import { h, createEvent, getAssetPath, proxyCustomElement } from '@stencil/core/internal/client';
export { setAssetPath } from '@stencil/core/internal/client';

/**
 * @param prefix {string} - Define el componente al que se le agregará la clase
 * @param modifiers {[string]} - Array de modificadores a convertir en clases
 * @returns {string} - Retorna los modificadores convertidos en clase de componente
 */
function modifiersToClass(prefix, modifers) {
  let propsToClass = [prefix];
  modifers.forEach(modifier => {
    if (typeof modifier == 'string') {
      propsToClass.push(`${prefix}--${modifier}`);
    }
    else if (typeof modifier == 'object') {
      if (Object.values(modifier)[0] === true) {
        propsToClass.push(`${prefix}--${Object.keys(modifier)[0]}`);
      }
    }
  });
  return propsToClass.join(' ');
}
/** Serie de expresiones regulares para validar el tipo de entrada de un campo de texto */
const regexValidators = {
  empty: /(?!^$|\s+)/,
  dni: /^[0-9]{8}$/,
  document: /^[A-Za-z0-9]{1,16}$/,
  email: /^[-\w.%+]{1,64}@(?:[A-Z0-9-]{1,63}\.){1,125}[A-Z]{2,63}$/i,
  cvv: /[0-9]{3,4}/,
  number: /[0-9]+/,
  numberFormat: /[0-9\.\,]+/,
  expiration: /^(0[1-9]|1[0-2])\/([2-9][0-9])$/
};
/**
 * Convierte un texto con acentos y mayúsculas y lo convierte a texto plano
 * @param text {string} Recibe el texto con acentos, mayúsculas, etc
 */
function convertToPlainString(text) {
  let plain = text.normalize('NFD').replace(/([^n\u0300-\u036f]|n(?!\u0303(?![\u0300-\u036f])))[\u0300-\u036f]+/gi, "$1").normalize();
  return plain.toLowerCase().trim();
}
/**
 * Retornará el siguiente elemento con el selector especificado, si no se especifica, retornará el siguiente inmediato.
 * @param element {HTMLElement} Elemento actual
 * @param selector {string} Selector a consultar
 */
function nextSibling(element, selector) {
  let sibling = element.nextElementSibling;
  if (!selector) {
    return sibling;
  }
  while (sibling) {
    if (sibling.matches(selector)) {
      return sibling;
    }
    sibling = sibling.nextElementSibling;
  }
}
/**
 * Retornará el anterior elemento con el selector especificado, si no se especifica, retornará el anterior inmediato.
 * @param element {HTMLElement} Elemento actual
 * @param selector {string} Selector a consultar
 */
function prevSibling(element, selector) {
  let sibling = element.previousElementSibling;
  if (!selector) {
    return sibling;
  }
  while (sibling) {
    if (sibling.matches(selector)) {
      return sibling;
    }
    sibling = sibling.previousElementSibling;
  }
}
/**
 * Retornará un arreglo con todos los elementos hermanos del elemento especificado
 * @param element {HTMLElement} Elemento actual
 * @param selector {string} Selector a consultar
 */
function allSiblings(element, selector) {
  let siblings = [];
  if (!element.parentNode) {
    return siblings;
  }
  const allChilds = element.parentNode.childNodes;
  allChilds.forEach((child) => {
    if (child != element && !child.matches(selector)) {
      siblings.push(child);
    }
  });
  return siblings;
}
/**
 * Retornará true cuando el elemento se encuentre visible en pantalla, de lo contrario retornará false
 * @param element {HTMLElement} Elemento a verificar
 * @param container {HTMLElement} Contenedor del elemento a verificar
 */
function visibilityValidate(element, container) {
  let visible = false;
  const containerTop = container.scrollTop;
  const containerBottom = containerTop + container.clientHeight;
  if (element != null) {
    const elemTop = element.offsetTop;
    const elemBottom = elemTop + element.clientHeight;
    visible = (containerBottom >= elemTop) && (elemBottom >= containerTop);
  }
  return visible;
}
/**
 * Retornará el mismo texto, con la primera letra en mayúscula
 * @param text {string} Texto en minúscula
 */
function firstCapitalice(text) {
  return text.replace(text.charAt(0), text.charAt(0).toUpperCase());
}
/**
 * Retornará el número con formato
 * @param value {number} Número sin formato
 */
function numberFormat(value) {
  const reverse = value.toString().split('').reverse();
  let arrays = [
    reverse.slice(0, 3),
    reverse.slice(3, 6),
    reverse.slice(6, 9),
    reverse.slice(9, 12)
  ];
  let str = '';
  arrays.forEach((a, i) => {
    if (a.length > 0) {
      str += (i > 0 ? ',' : '') + a.join('');
    }
  });
  return str.split('').reverse().join('');
}

const badgeCss = ".ibk-badge{display:inline-block;position:absolute;font-family:var(--fontGeometria);font-size:10px;text-transform:uppercase;color:white;padding:7px 10px;font-weight:500;top:0}.ibk-badge--info{background-color:var(--secondaryBlue1)}.ibk-badge--promo{background-color:var(--extendedWatermelon1)}.ibk-badge--left{border-radius:4px 0 4px 0;left:0}.ibk-badge--right{border-radius:0 4px 0 4px;right:0}";

const IbkBadge = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** <strong>Info: </strong> color azul<br>
     * <strong>Promo: </strong>color rojo
     */
    this.type = 'info';
    /** Posición en la que se encuentra ubicado el badge */
    this.position = "left";
    /** Le agrega el estilo position relative al contenedor del badge para posicionarlo correctamente */
    this.setPositionRelativeToParent = () => {
      this.host.parentElement.style.position = 'relative';
    };
  }
  componentWillLoad() {
    this.setPositionRelativeToParent();
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-badge', [
      this.type,
      this.position
    ]);
  }
  render() {
    return (h("div", { class: this.containerClass() }, this.text));
  }
  get host() { return this; }
  static get style() { return badgeCss; }
};

const breadcrumbCss = ".ibk-breadcrumb__container{display:inline-flex;align-items:center}.ibk-breadcrumb--separators .ibk-breadcrumb__container{border:solid var(--gray4);border-width:1px 0 1px 0;padding:30px 0}.ibk-breadcrumb__arrow{font-size:8px;color:var(--gray2);padding:3px 7px 0 7px}.ibk-breadcrumb--negative.ibk-breadcrumb--separators .ibk-breadcrumb__container{border-color:rgba(255,255,255,0.25)}.ibk-breadcrumb--negative .ibk-breadcrumb__arrow{color:rgba(255,255,255,0.25)}";

const IbkBreadcrumb = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Se agregarán las flechas entre cada item del breadcrum */
    this.addingArrows = () => {
      const items = this.host.querySelectorAll('ibk-breadcrumb-item');
      const parent = this.host.querySelector('.ibk-breadcrumb__container');
      Array.from(items, (item, index) => {
        if (index > 0) {
          const arrow = document.createElement('i');
          arrow.setAttribute('class', 'ibk-breadcrumb__arrow icon-xs-arrow-right');
          parent.insertBefore(arrow, item);
        }
        if (this.negative) {
          item.setAttribute('negative', '');
        }
      });
    };
  }
  componentDidLoad() {
    this.addingArrows();
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-breadcrumb', [
      { separators: this.separators },
      { negative: this.negative }
    ]);
  }
  render() {
    return (h("div", { class: this.containerClass() }, h("div", { class: "ibk-breadcrumb__container" }, h("slot", null))));
  }
  get host() { return this; }
  static get style() { return breadcrumbCss; }
};

const breadcrumbItemCss = ".ibk-breadcrumb-item{display:inline-block;font-family:var(--fontGeometria);text-transform:uppercase;font-size:12px;text-decoration:none;font-weight:600;letter-spacing:0.7px;transition:color var(--fast);cursor:pointer;color:var(--gray2)}.ibk-breadcrumb-item:not(.ibk-breadcrumb-item--current):active{transform:translateY(1px)}.ibk-breadcrumb-item:not(.ibk-breadcrumb-item--current):hover{color:var(--primaryGreen1)}.ibk-breadcrumb-item:not():hover{color:var(--primaryGreen1)}.ibk-breadcrumb-item--current{color:var(--grayText);cursor:default;pointer-events:none}.ibk-breadcrumb-item--negative{color:rgba(255, 255, 255, 0.4)}.ibk-breadcrumb-item--negative.ibk-breadcrumb-item--current{color:white}.ibk-breadcrumb-item--negative:not(.ibk-breadcrumb-item--current):hover{color:rgba(255, 255, 255, 0.7)}";

const IbkBreadcrumbItem = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onclick = createEvent(this, "onclick", 7);
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-breadcrumb-item', [
      { current: this.current },
      { negative: this.negative }
    ]);
  }
  render() {
    return (h("a", { class: this.containerClass(), href: this.href, onClick: this.onclick.emit }, this.text));
  }
  static get style() { return breadcrumbItemCss; }
};

const buttonCss = ".ibk-button{border:none;outline:none;appearance:none;background-color:transparent;display:inline-flex;justify-content:center;align-items:center;padding:0 30px;border-radius:4px;cursor:pointer;border:2px solid transparent;text-decoration:none;box-sizing:border-box;transition:background-color var(--fast), border-color var(--fast)}.ibk-button *{box-sizing:border-box}.ibk-button:active{transform:translateY(1px)}.ibk-button__text{font-weight:500;font-family:var(--fontGeometria);transition:color var(--fast);color:inherit;display:flex;align-items:center;justify-content:center}.ibk-button--primary{color:white}.ibk-button--primary.ibk-button--green{background-color:var(--primaryGreen1)}.ibk-button--primary.ibk-button--green:hover{background-color:var(--primaryGreen2)}.ibk-button--primary.ibk-button--blue{background-color:var(--secondaryBlue1)}.ibk-button--primary.ibk-button--blue:hover{background-color:var(--secondaryBlue2)}.ibk-button--secondary.ibk-button--green{border-color:var(--primaryGreen1);color:var(--primaryGreen1)}.ibk-button--secondary.ibk-button--green:hover{border-color:var(--primaryGreen2);color:var(--primaryGreen2)}.ibk-button--secondary.ibk-button--blue{border-color:var(--secondaryBlue1);color:var(--secondaryBlue1)}.ibk-button--secondary.ibk-button--blue:hover{border-color:var(--secondaryBlue2);color:var(--secondaryBlue2)}.ibk-button--tertiary.ibk-button--green{color:var(--primaryGreen1)}.ibk-button--tertiary.ibk-button--green:hover{color:var(--primaryGreen2)}.ibk-button--tertiary.ibk-button--blue{color:var(--secondaryBlue1)}.ibk-button--tertiary.ibk-button--blue:hover{color:var(--secondaryBlue2)}.ibk-button--small{height:40px;font-size:12px;padding:0 20px}.ibk-button--medium{height:48px;font-size:14px}.ibk-button--large{height:56px;font-size:14px}.ibk-button--full{width:100%}a.ibk-button--center{margin:auto;display:inline-flex}button.ibk-button--center{margin:auto;display:flex}@media screen and (max-width: 360px){.ibk-button--small{height:32px}.ibk-button--medium{height:44px}.ibk-button--large{height:48px}}.ibk-button__loader{display:inline-block;width:20px;height:20px;border:2px solid white;border-radius:50%;animation:ibk-button-loader 500ms linear infinite;pointer-events:none}@keyframes ibk-button-loader{0%{transform:rotate(0deg)}0%{transform:rotate(-360deg)}}.ibk-button--primary .ibk-button__loader{border-top-color:rgba(255,255,255,0.2);border-left-color:rgba(255,255,255,0.2);border-right-color:rgba(255,255,255,0.2)}.ibk-button--secondary.ibk-button--green .ibk-button__loader,.ibk-button--tertiary.ibk-button--green .ibk-button__loader{border-top-color:var(--primaryGreen4);border-left-color:var(--primaryGreen4);border-right-color:var(--primaryGreen4);border-bottom-color:var(--primaryGreen1)}.ibk-button--secondary.ibk-button--blue .ibk-button__loader,.ibk-button--tertiary.ibk-button--blue .ibk-button__loader{border-top-color:var(--secondaryBlue1);border-left-color:var(--secondaryBlue1);border-right-color:var(--secondaryBlue1)}.ibk-button--negative.ibk-button--primary{background-color:white}.ibk-button--negative.ibk-button--green.ibk-button--primary .ibk-button__text{color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--blue.ibk-button--primary .ibk-button__text{color:var(--secondaryBlue1)}.ibk-button--negative.ibk-button--primary:hover{background-color:var(--gray5)}.ibk-button--negative.ibk-button--primary.ibk-button--green:hover .ibk-button__text{color:var(--primaryGreen2)}.ibk-button--negative.ibk-button--primary.ibk-button--blue:hover .ibk-button__text{color:var(--secondaryBlue2)}.ibk-button--negative.ibk-button--primary.ibk-button--green .ibk-button__loader{border-top-color:var(--primaryGreen4);border-left-color:var(--primaryGreen4);border-right-color:var(--primaryGreen4);border-bottom-color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--primary.ibk-button--blue .ibk-button__loader{border-top-color:var(--secondaryBlue4);border-left-color:var(--secondaryBlue4);border-right-color:var(--secondaryBlue4);border-bottom-color:var(--secondaryBlue1)}.ibk-button--negative.ibk-button--primary.ibk-button--green.ibk-button--disable{background-color:var(--primaryGreen2)}.ibk-button--negative.ibk-button--primary.ibk-button--blue.ibk-button--disable{background-color:var(--secondaryBlue2)}.ibk-button--negative.ibk-button--primary .ibk-button__text{color:var(--primaryGreen1)}.ibk-button--negative.ibk-button--secondary{border-color:white}.ibk-button--negative.ibk-button--secondary:hover{border-color:var(--gray5)}.ibk-button--negative.ibk-button--secondary:hover .ibk-button__text{color:var(--gray5)}.ibk-button--negative.ibk-button--secondary .ibk-button__text{color:white}.ibk-button--negative.ibk-button--secondary .ibk-button__loader{border-top-color:var(--gray1);border-left-color:var(--gray1);border-right-color:var(--gray1);border-bottom-color:var(--gray4)}.ibk-button--negative.ibk-button--secondary:hover .ibk-button__text{color:var(--gray5)}.ibk-button--negative.ibk-button--tertiary.ibk-button--green.ibk-button--disable .ibk-button__text{color:var(--primaryGreen2)}.ibk-button--negative.ibk-button--tertiary.ibk-button--blue.ibk-button--disable .ibk-button__text{color:var(--secondaryBlue2)}.ibk-button--negative.ibk-button--tertiary .ibk-button__text{color:white}.ibk-button--negative.ibk-button--tertiary .ibk-button__loader{border-top-color:var(--gray1);border-left-color:var(--gray1);border-right-color:var(--gray1);border-bottom-color:var(--gray4)}.ibk-button--disable{cursor:default;pointer-events:none}.ibk-button--disable.ibk-button--primary{background-color:var(--gray4);color:var(--gray2)}.ibk-button--disable.ibk-button--secondary{border-color:var(--gray4);color:var(--gray2)}.ibk-button--disable.ibk-button--tertiary{color:var(--gray2)}.ibk-button__icon{font-size:18px;color:inherit}.ibk-button--icon-right .ibk-button__icon{padding-left:2px}.ibk-button--icon-left .ibk-button__icon{padding-right:2px}";

const IbkButton = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onclick = createEvent(this, "onclick", 7);
    /**
     * <strong>primary:</strong> Fondo de color con texto blanco <br>
     * <strong>secondary:</strong> Fondo transparente con borde y texto verde <br>
     * <strong>tertiary:</strong> Texto verde sin fondo ni borde
     */
    this.appearance = 'primary';
    /** Define si el botón será de color verde o azul. Por defecto será verde. */
    this.color = 'green';
    /** Alto del botón, 40px, 48px y 56px respectivamente en desktop y 32px, 44px, 48px en mobile */
    this.size = 'medium';
    /** Define el tipo del botón, se usarán los tipos nativos */
    this.type = 'button';
    /** Determina si el botón se encuentra sobre un fondo oscuro */
    this.negative = false;
    /** Cuando está en true, se mostrará un icono con una animación de carga. */
    this.loading = false;
    /** Determina si usará el 100% del espacio disponible */
    this.full = false;
    /** Determina si el botón irá al centro de la pantalla */
    this.center = false;
    /** Determina si le botón se encuentra deshabilitado */
    this.disable = false;
    /** Determina si el enlace se abre en una nueva ventana o en la misma */
    this.hrefTarget = '_self';
  }
  componentDidLoad() {
    setTimeout(() => {
      this._buttonElement = this.host.querySelector('.ibk-button');
      this._sizeButton = this._buttonElement.getBoundingClientRect().width;
      if (this.text != undefined && this.icon != undefined && this.iconPosition == undefined) {
        this.iconPosition = 'right';
      }
      if (this.full || this.center) {
        this.host.style.width = "100%";
      }
    }, 100);
  }
  onLoadingChange(loading) {
    if (loading && loading === true && !this.href) {
      this._buttonElement.style.width = `${this._sizeButton}px`;
    }
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-button', [
      this.appearance,
      this.size,
      this.color,
      this.iconPosition && `icon-${this.iconPosition}`,
      { full: this.full },
      { disable: this.disable },
      { negative: this.negative },
      { center: this.center }
    ]);
  }
  render() {
    if (this.href) {
      return (h("a", { class: this.containerClass(), href: this.href, onClick: this.onclick.emit, target: this.hrefTarget }, h("span", { class: "ibk-button__text" }, this.text)));
    }
    else {
      return (h("button", { class: this.containerClass(), type: this.type, onClick: this.onclick.emit }, !this.loading ?
        h("span", { class: "ibk-button__text" }, this.icon && this.iconPosition == 'left' && h("i", { class: 'ibk-button__icon ' + this.icon }), this.text, this.icon && this.iconPosition == 'right' && h("i", { class: 'ibk-button__icon ' + this.icon }))
        :
          h("span", { class: "ibk-button__loader" })));
    }
  }
  get host() { return this; }
  static get watchers() { return {
    "loading": ["onLoadingChange"]
  }; }
  static get style() { return buttonCss; }
};

const buttonInlineCss = ".ibk-button-inline{appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:none;background-color:transparent;box-sizing:border-box;height:48px;display:inline-flex;align-items:center;justify-content:center;cursor:pointer;transition:background-color var(--fast);padding:0 10px;border-radius:4px;text-decoration:none}.ibk-button-inline:hover{background-color:var(--gray5)}.ibk-button-inline:active{transform:translateY(1px)}.ibk-button-inline *{box-sizing:border-box}.ibk-button-inline__text{color:var(--primaryGreen1);font-size:14px;font-weight:500;font-family:var(--fontGeometria)}.ibk-button-inline__icon{color:var(--primaryGreen1);font-size:18px}.ibk-button-inline--icon-left .ibk-button-inline__icon{margin-right:7px}.ibk-button-inline--icon-right .ibk-button-inline__icon{margin-left:7px;order:2}";

const IbkButtonInline = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onclick = createEvent(this, "onclick", 7);
    /** Posición del ícono si existiera */
    this.iconPosition = 'left';
    /** Determina si le botón se encuentra deshabilitado */
    this.disable = false;
    /** Determina si el enlace se abre en una nueva ventana o en la misma */
    this.hrefTarget = '_self';
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-button-inline', [`icon-${this.iconPosition}`]);
    };
  }
  render() {
    if (this.href) {
      return (h("a", { href: this.href, target: this.hrefTarget, class: this.containerClass() }, this.icon && h("i", { class: 'ibk-button-inline__icon ' + this.icon }), this.text && h("span", { class: "ibk-button-inline__text" }, this.text)));
    }
    else {
      return (h("button", { type: "button", class: this.containerClass(), onClick: this.onclick.emit }, this.icon && h("i", { class: 'ibk-button-inline__icon ' + this.icon }), this.text && h("span", { class: "ibk-button-inline__text" }, this.text)));
    }
  }
  static get style() { return buttonInlineCss; }
};

const calendarCss = ".ibk-calendar{box-sizing:border-box;color:var(--grayText);width:330px;display:inline-block}.ibk-calendar *{box-sizing:border-box}.ibk-calendar__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-calendar__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-calendar__selector{border:1px solid var(--gray4);border-radius:4px;height:48px;display:inline-flex;align-items:center;cursor:pointer;transition:var(--fast);width:100%;background-color:white}.ibk-calendar__selector:hover{border-color:var(--gray3)}.ibk-calendar__input{appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;font-family:var(--fontGeometria);font-weight:500;font-size:16px;height:100%;pointer-events:none;padding:0 5px;outline:none;width:100%}.ibk-calendar__input::placeholder{color:var(--gray2);font-weight:400}.ibk-calendar__icon{font-size:20px;color:var(--primaryGreen1);padding:0 10px 0 15px;pointer-events:none}.ibk-calendar__arrow{padding:0 15px;color:var(--primaryGreen1);font-size:6px;pointer-events:none;text-align:center;transition:var(--fast)}.ibk-calendar__dates{position:absolute;border:1px solid var(--gray4);border-radius:4px;z-index:1;background-color:white}.ibk-calendar__range-selector{display:flex;align-items:center;justify-content:space-between;margin:20px 20px 0 20px;border:1px solid var(--gray4);border-radius:4px}.ibk-calendar__range-selector__button{width:calc(100% / 3);appearance:none;-webkit-appearance:none;-moz-appearance:none;background-color:transparent;border:none;height:46px;color:var(--gray2);font-family:var(--fontGeometria);font-size:16px;cursor:pointer;transition:var(--fast);border-radius:2px;outline:none;position:relative}.ibk-calendar__range-selector__button:not(.ibk-calendar__range-selector__button--selected):hover{background-color:var(--gray5)}.ibk-calendar__range-selector__button:nth-child(2)::before,.ibk-calendar__range-selector__button:nth-child(2)::after{content:'';display:block;height:100%;width:1px;background-color:var(--gray4);position:absolute;top:0;z-index:1}.ibk-calendar__range-selector__button:nth-child(2)::before{left:0}.ibk-calendar__range-selector__button:nth-child(2)::after{right:0}.ibk-calendar__range-selector__button--selected{background-color:var(--primaryGreen1);color:white;font-weight:500;-webkit-box-shadow:0px 0px 0px 1px var(--primaryGreen1);-moz-box-shadow:0px 0px 0px 1px var(--primaryGreen1);box-shadow:0px 0px 0px 1px var(--primaryGreen1);z-index:1}.ibk-calendar__range-selector__button--selected:nth-child(2)::before,.ibk-calendar__range-selector__button--selected:nth-child(2)::after{background-color:var(--primaryGreen1)}.ibk-calendar__months{display:flex;align-items:flex-start}.ibk-calendar__month{padding:20px;display:inline-block}.ibk-calendar__month-name{font-family:var(--fontMontserrat);font-size:14px;display:block;text-align:center;margin-bottom:20px;font-weight:500;position:relative}.ibk-calendar__month-arrow{position:absolute;font-size:10px;color:var(--primaryGreen1);cursor:pointer;width:30px;height:16px;display:inline-flex;align-items:center;justify-content:center;padding-top:2px}.ibk-calendar__month-arrow.icon-xs-arrow-left{left:0}.ibk-calendar__month-arrow.icon-xs-arrow-right{right:0}.ibk-calendar__month-arrow:active{transform:translateY(1px)}.ibk-calendar__day-name{font-family:var(--fontGeometria);font-size:12px;color:var(--gray2);font-weight:500;display:inline-flex;align-items:center;justify-content:center;width:44px;height:30px;text-align:center;cursor:default}.ibk-calendar__days{display:flex;align-items:center}.ibk-calendar__days:not(:last-child){margin-bottom:3px}.ibk-calendar__day-number{font-family:var(--fontGeometria);font-size:13px;display:inline-flex;height:44px;width:44px;align-items:center;justify-content:center;font-weight:500;cursor:pointer;border-radius:50%;transition:background-color var(--fast);user-select:none;background-color:transparent;border:none;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;position:relative}.ibk-calendar__day-number__text{z-index:1}.ibk-calendar__day-number:not(.ibk-calendar__day-number--selected):hover{background-color:var(--gray4)}.ibk-calendar__day-number:active{transform:translateY(1px)}.ibk-calendar__day-number--disabled{pointer-events:none;color:var(--gray3)}.ibk-calendar__day-number--range::before{content:'';position:absolute;height:100%;width:100%;background-color:#f7f7f7;z-index:-1}.ibk-calendar__day-number--range:first-child:before{border-radius:4px 0 0 4px}.ibk-calendar__day-number--range:last-child:not(.ibk-calendar__day-number--shadow-out):before{border-radius:0 4px 4px 0}.ibk-calendar__day-number--selected{background-color:var(--grayText);color:white;font-size:14px;border-radius:50%}.ibk-calendar__day-number--init-range::before,.ibk-calendar__day-number--end-range::before{content:'';position:absolute;height:100%;width:50%;background-color:#f7f7f7;z-index:-1}.ibk-calendar__day-number--init-range::before{right:0}.ibk-calendar__day-number--end-range::before{left:0}.ibk-calendar__day-number--shadow-in::after,.ibk-calendar__day-number--shadow-out::after{content:'';position:absolute;height:100%;width:100%;z-index:-1}.ibk-calendar__day-number--shadow-in::after,.ibk-calendar--range .ibk-calendar__day-number--shadow-in::after{background:linear-gradient(90deg, rgba(255,255,255,1) 50%, rgba(247,247,247,1) 100%);right:100%}.ibk-calendar__day-number--shadow-out::after,.ibk-calendar--range .ibk-calendar__day-number--shadow-out::after{background:linear-gradient(-90deg, rgba(255,255,255,1) 50%, rgba(247,247,247,1) 100%);left:100%}.ibk-calendar--full{width:100%}.ibk-calendar__day-number--over::before{content:'';position:absolute;height:100%;width:100%;background-color:#f7f7f7;z-index:-1}.ibk-calendar--open .ibk-calendar__arrow{transform:rotate(-180deg)}.ibk-calendar--error .ibk-calendar__selector{border-color:var(--extendedWatermelon1)}.ibk-calendar--error .ibk-calendar__icon{color:var(--extendedWatermelon1)}.ibk-calendar__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}";

const IbkCalendar = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onselect = createEvent(this, "onselect", 7);
    /** Define un placeholder en el selector */
    this.placeholder = 'dd/mm/aaaa';
    /** Define la cantidad de meses a mostrar en el selector */
    this.months = 1;
    /** Si la candidad de meses a mostrar es 2, define si se muestra el mes siguiente o anterior */
    this.showMonth = 'next';
    /** Define hacia que lado se abrirá el calendario */
    this.openTo = 'bottom-right';
    /** Define si se podrá seleccionar un rango de fechas */
    this.multiselect = false;
    /** El selector del calendario ocupará el 100% del espacio disponible */
    this.full = false;
    /** Se mostrará un mensaje de error */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el calendario se encuentra vacío, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Por favor selecciona una fecha';
    /** Define si el calendario no contará con manejo de errores. Se omitirá el espacio generado para el mensaje de error */
    this.noHandlingError = false;
    /** Determina si se está mostrando o no el calendario */
    this._showingDates = false;
    /** Fecha inicial a mostra en el calendario */
    this._currentDate = new Date();
    /** Almacena temporalmente el rango mientras se va seleccionando */
    this._tempRange = [];
    /** Configurar algunas opciones en base a las propiedades usadas */
    this.config = () => {
      if (this.multiselect) {
        this.selectedDate = undefined;
        this.placeholder = 'dd/mm/aaaa - dd/mm/aaaa';
        this._settedMultiselect = true;
      }
      else {
        this.selectedDates = undefined;
      }
      if (this.rangeSelector == '') {
        this.rangeSelector = 'none';
      }
      else {
        this.selectRange(null, this.rangeSelector);
      }
    };
    /** Evento al cambiar el tamaño de la pantalla */
    this.resizeWindow = () => {
      window.onresize = () => {
        this.getDatesPosition();
      };
    };
    /** Cierra el dropdown al hacer click fuera del mismo */
    this.bodyClick = () => {
      const body = document.querySelector('body');
      body.addEventListener('click', e => {
        const t = e.target;
        const closest = t.closest('.ibk-calendar');
        if (closest == null) {
          this._showingDates = false;
        }
      });
    };
    /** Define la fecha con el mes siguiente o anterior dependiendo del mes a mostrar */
    this.setOtherDate = () => {
      if (this.selectedDates != undefined) {
        this.host.setAttribute('show-month', 'prev');
      }
      if (this.months == 2) {
        if (this.showMonth == 'next') {
          this._otherDate = new Date(new Date().setMonth(new Date().getMonth() + 1));
        }
        else {
          this._otherDate = new Date(new Date().setMonth(new Date().getMonth() - 1));
        }
      }
    };
    /** Obtener la cantidad de dias que hay por mes */
    this.getDaysPerMonth = (month, year) => {
      let date = new Date(year, month + 1, 0);
      return date.getDate();
    };
    /** Obtener un arreglo por cada semana del mes que contiene los dias y sus estados */
    this.getWeeksPerMonth = (month, year) => {
      let weeks = new Array();
      let firstDay = new Date(year, month, 1).getDay();
      firstDay = firstDay == 0 ? 7 : firstDay;
      let days = new Date(year, month + 1, 0).getDate();
      let allDays = [];
      let day = 1;
      for (let i = 1; i < firstDay; i++) {
        allDays.push(0);
      }
      while (day <= days) {
        allDays.push(day);
        day++;
      }
      let tempWeek = new Array();
      Array.from(allDays, (day) => {
        let d = {};
        if (day != 0) {
          const tempDate = new Date(year, month, day);
          d.day = day;
          if (this.initialDate != undefined && tempDate < this.parseDate(this.initialDate) ||
            this.endDate != undefined && tempDate > this.parseDate(this.endDate)) {
            d.disabled = true;
          }
          else {
            d.disabled = false;
          }
          if (this.selectedDate != undefined && this.parseDate(this.selectedDate).getTime() == tempDate.getTime()) {
            d.selected = true;
          }
          else {
            d.selected = false;
          }
          if (this.selectedDates != undefined) {
            const splitted = this.selectedDates.split('-');
            if (this.parseDate(splitted[0]).getTime() == tempDate.getTime() || this.parseDate(splitted[1]).getTime() == tempDate.getTime()) {
              d.selected = true;
            }
            if (this.parseDate(splitted[0]).getTime() == tempDate.getTime()) {
              d.initRange = true;
            }
            if (this.parseDate(splitted[1]).getTime() == tempDate.getTime()) {
              d.endRange = true;
            }
            if (this.parseDate(splitted[0]) <= tempDate && this.parseDate(splitted[1]) >= tempDate) {
              d.range = true;
            }
          }
          if (this._tempRange.length == 1 && this._tempOverRange != undefined) {
            if (this._tempOverRange > this._tempRange[0].date && tempDate > this._tempRange[0].date && tempDate < this._tempOverRange) {
              d.over = true;
            }
            if (this._tempOverRange > this._tempRange[0].date && tempDate.getTime() == this._tempOverRange.getTime()) {
              d.endRange = true;
            }
          }
          if (this._tempOverRange == undefined && !this.multiselect) {
            d.range = false;
            d.initRange = false;
            d.endRange = false;
          }
        }
        tempWeek.push(d);
      });
      Array.from(tempWeek, (_, index) => {
        if (index % 7 == 0) {
          let sliced = tempWeek.slice(index, index + 7);
          if (sliced.length > 0) {
            weeks.push(sliced);
          }
        }
      });
      return weeks;
    };
    /** Retorna el nombre del mes basado en el índice */
    this.getMonthName = (month) => {
      const monthNames = ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio', 'Agosto', 'Setiembre', 'Octubre', 'Noviembre', 'Diciembre'];
      return monthNames[month];
    };
    /** Obtiene la fecha en formato "DD/MM/YYYY" y lo convierte a formato Date */
    this.parseDate = (date) => {
      const splitted = date.split('/');
      return new Date(parseInt(splitted[2]), parseInt(splitted[1]) - 1, parseInt(splitted[0]));
    };
    /** Arreglo que contiene los días del mes actual, además del mes anterior o posterior dependiendo del mes a mostrar */
    this.drawDates = () => {
      let dates = new Array();
      let currentMonth = {
        month: this._currentDate.getMonth(),
        year: this._currentDate.getFullYear(),
        weeks: this.getWeeksPerMonth(this._currentDate.getMonth(), this._currentDate.getFullYear()),
        days: this.getDaysPerMonth(this._currentDate.getMonth(), this._currentDate.getFullYear())
      };
      dates.push(currentMonth);
      if (this.months == 2) {
        let otherMonth = {
          month: this._otherDate.getMonth(),
          year: this._otherDate.getFullYear(),
          weeks: this.getWeeksPerMonth(this._otherDate.getMonth(), this._otherDate.getFullYear()),
          days: this.getDaysPerMonth(this._otherDate.getMonth(), this._otherDate.getFullYear())
        };
        if (this.showMonth == 'next') {
          dates.push(otherMonth);
        }
        else {
          dates.unshift(otherMonth);
        }
      }
      return dates;
    };
    /** Obtener la posición del selector para abrir las fechas en base a su posición */
    this.getDatesPosition = () => {
      const selector = this.host.querySelector('.ibk-calendar__selector');
      let position = { top: 'auto', right: 'auto', bottom: 'auto', left: 'auto' };
      if (this.openTo == 'bottom-right') {
        position.top = `${selector.offsetTop + selector.getBoundingClientRect().height - 1}px`;
        position.left = `${selector.offsetLeft}px`;
      }
      else if (this.openTo == 'bottom-left') {
        position.top = `${selector.offsetTop + selector.getBoundingClientRect().height - 1}px`;
        position.right = `${window.innerWidth - selector.getBoundingClientRect().width - selector.offsetLeft}px`;
      }
      else if (this.openTo == 'top-right') {
        position.bottom = `${window.innerHeight - selector.offsetTop - 1}px`;
        position.left = `${selector.offsetLeft}px`;
      }
      else if (this.openTo == 'top-left') {
        position.bottom = `${window.innerHeight - selector.offsetTop - 1}px`;
        position.right = `${window.innerWidth - selector.getBoundingClientRect().width - selector.offsetLeft}px`;
      }
      this._datesPosition = position;
    };
    /** Muestra u oculta el calendario */
    this.toggleDates = () => {
      this._showingDates = !this._showingDates;
      this.getDatesPosition();
    };
    /** Configura la clase del día basado en estados y modificadores */
    this.setContainerDayClass = (day, monthDays) => {
      var _a;
      return modifiersToClass('ibk-calendar__day-number', [
        { disabled: (_a = day.disabled) !== null && _a !== void 0 ? _a : true },
        { selected: day.selected },
        { range: day.range },
        { 'init-range': day.initRange },
        { 'end-range': day.endRange },
        { 'shadow-in': day.day == 1 && day.range },
        { 'shadow-out': monthDays != undefined && day.day == monthDays && day.range },
        { over: day.over }
      ]);
    };
    /** Configura el valor del selector */
    this.setSelectorValue = () => {
      if (this.selectedDate) {
        return this.selectedDate;
      }
      else if (this.selectedDates) {
        return this.selectedDates.split('-').join(' - ');
      }
      else {
        return '';
      }
    };
    /** Recibe un formato Date y lo transforma a DD/MM/YYYY */
    this.parseDateToString = (date) => {
      const day = date.getDate().toString().length == 1 ? ('0' + date.getDate()) : date.getDate();
      const month = date.getMonth().toString().length == 1 ? ('0' + (date.getMonth() + 1)) : date.getMonth() + 1;
      return `${day}/${month}/${date.getFullYear()}`;
    };
    /** Función al seleccionar una fecha única o rango */
    this.selectDate = (e, year, month, day) => {
      let emit = {};
      const t = e.target;
      const otherSelected = this.host.querySelectorAll('.ibk-calendar__day-number--selected');
      const selectedDate = new Date(year, month, day);
      this.host.setAttribute('range-selector', 'none');
      if (this._settedMultiselect != undefined) {
        this.host.setAttribute('multiselect', '');
      }
      else {
        this.host.removeAttribute('multiselect');
        this._tempOverRange = null;
      }
      if (!this.multiselect || (this.multiselect && this._tempRange.length == 0)) {
        Array.from(otherSelected, (button) => button.classList.remove('ibk-calendar__day-number--selected'));
      }
      const rangeButton = this.host.querySelector('.ibk-calendar__range-selector__button--selected');
      if (rangeButton != undefined) {
        rangeButton.classList.remove('ibk-calendar__range-selector__button--selected');
      }
      if (!this.multiselect) {
        this.host.removeAttribute('error');
        t.classList.add('ibk-calendar__day-number--selected');
        emit.date = selectedDate,
          emit.parsedDate = this.parseDateToString(selectedDate);
        this.onselect.emit(emit);
        this.host.setAttribute('selected-date', this.parseDateToString(selectedDate));
        this.host.removeAttribute('selected-dates');
      }
      else {
        t.classList.add('ibk-calendar__day-number--selected');
        if (this._tempRange.length == 1 && this._tempRange[0].date >= selectedDate) {
          Array.from(otherSelected, (button) => button.classList.remove('ibk-calendar__day-number--selected'));
          this._tempRange = [];
        }
        emit.date = selectedDate;
        emit.parsedDate = this.parseDateToString(selectedDate);
        this._tempRange.push(emit);
        this.onselect.emit(this._tempRange);
        this.host.setAttribute('selected-dates', `${this.parseDateToString(this._tempRange[0].date)}-${this._tempRange[1] ? this.parseDateToString(this._tempRange[1].date) : ''}`);
        this.host.removeAttribute('selected-date');
        if (this._tempRange.length == 2) {
          this.host.removeAttribute('error');
          this._tempRange = [];
        }
      }
    };
    /** Cambia el calendario dependiendo de la flecha seleccionada */
    this.changeMonth = (to) => {
      this._currentDate.setDate(1);
      this.months == 2 && this._otherDate.setDate(1);
      if (to == 'next') {
        this._currentDate = new Date(this._currentDate.setMonth(this._currentDate.getMonth() + 1));
        this.months == 2 && (this._otherDate = new Date(this._otherDate.setMonth(this._otherDate.getMonth() + 1)));
      }
      else {
        this._currentDate = new Date(this._currentDate.setMonth(this._currentDate.getMonth() - 1));
        this.months == 2 && (this._otherDate = new Date(this._otherDate.setMonth(this._otherDate.getMonth() - 1)));
      }
    };
    /** Selecciona un rango entre dìa, semana y mes */
    this.selectRange = (e, choose) => {
      const otherRanges = this.host.querySelectorAll('.ibk-calendar__range-selector__button');
      Array.from(otherRanges, (button) => button.classList.remove('ibk-calendar__range-selector__button--selected'));
      if (e != null) {
        const t = e.target;
        t.classList.add('ibk-calendar__range-selector__button--selected');
      }
      if (choose == 'day') {
        this.host.removeAttribute('multiselect');
        this.host.removeAttribute('selected-dates');
        this.host.setAttribute('selected-date', this.parseDateToString(new Date()));
        this.host.setAttribute('range-selector', 'day');
        this.onselect.emit({
          date: new Date(),
          parsedDate: this.parseDateToString(new Date())
        });
      }
      else if (choose == 'week') {
        this.host.setAttribute('multiselect', '');
        this.host.removeAttribute('selected-date');
        this.host.setAttribute('selected-dates', `${this.parseDateToString(new Date(new Date().setDate(new Date().getDate() - 7)))}-${this.parseDateToString(new Date())}`);
        this.host.setAttribute('range-selector', 'week');
        this.onselect.emit([
          {
            date: new Date(new Date().setDate(new Date().getDate() - 7)),
            parsedDate: this.parseDateToString(new Date(new Date().setDate(new Date().getDate() - 7)))
          },
          {
            date: new Date(),
            parsedDate: this.parseDateToString(new Date())
          }
        ]);
      }
      else if (choose == 'month') {
        this.host.setAttribute('multiselect', '');
        this.host.removeAttribute('selected-date');
        this.host.setAttribute('selected-dates', `${this.parseDateToString(new Date(new Date().setMonth(new Date().getMonth() - 1)))}-${this.parseDateToString(new Date())}`);
        this.host.setAttribute('range-selector', 'month');
        this.onselect.emit([
          {
            date: new Date(new Date().setMonth(new Date().getMonth() - 1)),
            parsedDate: this.parseDateToString(new Date(new Date().setMonth(new Date().getMonth() - 1)))
          },
          {
            date: new Date(),
            parsedDate: this.parseDateToString(new Date())
          }
        ]);
      }
      this._currentDate = new Date();
      this.setOtherDate();
    };
    /** Hace efecto over sobre el botón del día y aplica un fondo cuando se esta seleccionando un rango de fechas */
    this.overDay = (year, month, day) => {
      if (this._tempRange.length == 1) {
        const overedDate = new Date(year, month, day);
        this._tempOverRange = overedDate;
      }
    };
    /** Detecta cuando el mouse deja de hacer over sobre el botón del día */
    this.leaveDay = (e) => {
      const related = e.relatedTarget;
      if (!related.classList.contains('ibk-calendar__day-number')) {
        this._tempOverRange = null;
      }
    };
  }
  componentDidLoad() {
    this.resizeWindow();
    this.bodyClick();
  }
  componentWillLoad() {
    this.config();
    this.setOtherDate();
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-calendar', [
      { full: this.full },
      { range: this._tempRange.length == 1 },
      { open: this._showingDates },
      { error: this.error }
    ]);
  }
  render() {
    return (h("div", { class: this.containerClass() }, this.label && h("span", { class: "ibk-calendar__label" }, this.label), this.subtitle && h("span", { class: "ibk-calendar__subtitle" }, this.subtitle), h("div", { class: "ibk-calendar__selector", onClick: this.toggleDates }, h("i", { class: "ibk-calendar__icon icon-m-calendar" }), h("input", { class: "ibk-calendar__input", type: "text", readonly: true, value: this.setSelectorValue(), placeholder: this.placeholder }), h("i", { class: "ibk-calendar__arrow icon-xs-arrow-down" })), !this.noHandlingError && h("span", { class: "ibk-calendar__error-message" }, this.error && this.requiredMessage), this._showingDates &&
      h("div", { class: "ibk-calendar__dates", style: this._datesPosition }, (this.rangeSelector && this.months == 2) &&
        h("div", { class: "ibk-calendar__range-selector" }, h("button", { type: "button", onClick: (e) => this.selectRange(e, 'day'), class: 'ibk-calendar__range-selector__button' + (this.rangeSelector == 'day' ? ' ibk-calendar__range-selector__button--selected' : '') }, "D\u00EDa"), h("button", { type: "button", onClick: (e) => this.selectRange(e, 'week'), class: 'ibk-calendar__range-selector__button' + (this.rangeSelector == 'week' ? ' ibk-calendar__range-selector__button--selected' : '') }, "\u00DAltima semana"), h("button", { type: "button", onClick: (e) => this.selectRange(e, 'month'), class: 'ibk-calendar__range-selector__button' + (this.rangeSelector == 'month' ? ' ibk-calendar__range-selector__button--selected' : '') }, "\u00DAltimo mes")), h("div", { class: "ibk-calendar__months" }, Array.from(this.drawDates(), (date, index) => {
        return (h("div", { class: "ibk-calendar__month" }, h("p", { class: "ibk-calendar__month-name" }, (this.months == 2 && index == 0 || this.months == 1) && h("i", { class: "ibk-calendar__month-arrow icon-xs-arrow-left", onClick: () => this.changeMonth('prev') }), this.getMonthName(date.month), " ", date.year, (this.months == 2 && index == 1 || this.months == 1) && h("i", { class: "ibk-calendar__month-arrow icon-xs-arrow-right", onClick: () => this.changeMonth('next') })), h("div", { class: "ibk-calendar__days" }, h("span", { class: "ibk-calendar__day-name" }, "lu"), h("span", { class: "ibk-calendar__day-name" }, "ma"), h("span", { class: "ibk-calendar__day-name" }, "mi"), h("span", { class: "ibk-calendar__day-name" }, "ju"), h("span", { class: "ibk-calendar__day-name" }, "vi"), h("span", { class: "ibk-calendar__day-name" }, "s\u00E1"), h("span", { class: "ibk-calendar__day-name" }, "do")), Array.from(date.weeks, (week) => {
          return (h("div", { class: "ibk-calendar__days" }, Array.from(week, (day) => {
            return h("button", { type: "button", class: this.setContainerDayClass(day, date.days), onClick: (e) => this.selectDate(e, date.year, date.month, day.day), onMouseOver: () => this.overDay(date.year, date.month, day.day), onMouseLeave: this.leaveDay }, day.day);
          })));
        })));
      })))));
  }
  get host() { return this; }
  static get style() { return calendarCss; }
};

const checkboxCss = ".ibk-checkbox{padding:5px 0}.ibk-checkbox *{box-sizing:border-box}.ibk-checkbox__hidden{display:none}.ibk-checkbox__label{display:inline-flex;align-items:flex-start;color:var(--grayText);cursor:pointer}.ibk-checkbox__icon{display:inline-flex;align-items:center;justify-content:center;min-height:18px;min-width:18px;border:2px solid var(--gray4);border-radius:3px;margin-right:7px}.ibk-checkbox__check{color:white;font-size:9px;width:0;overflow:hidden;transition:var(--slow);text-align:center;transform:translateX(-3px)}.ibk-checkbox__label:active{transform:translateY(1px)}.ibk-checkbox__text{font-family:var(--fontGeometria);font-size:14px;font-weight:500;line-height:18px}.ibk-checkbox__text a{text-decoration:none;color:var(--primaryGreen1)}.ibk-checkbox__error-message{color:var(--extendedWatermelon1);font-size:12px;font-family:var(--fontMontserrat);font-weight:500;min-height:15px;margin-top:7px;display:block}.ibk-checkbox--icon-only .ibk-checkbox__icon{margin:0}.ibk-checkbox--checked .ibk-checkbox__icon{background-color:var(--primaryGreen1);border-color:var(--primaryGreen1)}.ibk-checkbox--checked .ibk-checkbox__check{color:white;width:100%;transform:translateX(0)}.ibk-checkbox--disabled{pointer-events:none}.ibk-checkbox--disabled .ibk-checkbox__icon{background-color:var(--gray4);border-color:var(--gray2)}.ibk-checkbox--disabled.ibk-checkbox--checked .ibk-checkbox__icon{border-color:var(--gray4)}.ibk-checkbox--disabled .ibk-checkbox__check{color:var(--gray2)}.ibk-checkbox--error .ibk-checkbox__icon{border-color:var(--extendedWatermelon1)}.ibk-checkbox--right .ibk-checkbox__label{justify-content:space-between}.ibk-checkbox--right .ibk-checkbox__icon{margin-right:0;margin-left:7px;order:2}.ibk-checkbox--outline .ibk-checkbox__label{border:1px solid var(--gray4);border-radius:4px;padding:10px}.ibk-checkbox--full .ibk-checkbox__label{width:100%}.ibk-checkbox--focus .ibk-checkbox__icon{border-color:var(--primaryGreen1)}";

const IbkCheckbox = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onchecked = createEvent(this, "onchecked", 7);
    /** Estado activo del checkbox */
    this.checked = false;
    /** Estado inactivo del checkbox */
    this.disabled = false;
    /** Error en el checkbox */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el checkbox se encuentra deseleccionado, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Este campo es requerido';
    /** Determina si el checkbox ocupa el 100% de la pantalla */
    this.full = false;
    /** Determina la posición del ícono */
    this.iconPosition = 'left';
    /** El checkbox se verá envuelto en una caja */
    this.outline = false;
    /** El checkbox estará agrupado en "ibk-checkbox-group" */
    this._grouped = false;
    /** Estado focus del checkbox */
    this._focus = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-checkbox', [
        this.iconPosition,
        { outline: this.outline },
        { checked: this.checked },
        { disabled: this.disabled },
        { error: this.error },
        { full: this.full },
        { focus: this._focus },
        { 'icon-only': !this.label }
      ]);
    };
  }
  componentWillLoad() {
    this.groupVerification();
  }
  /** Detecta cuando el estado del checkbox cambia */
  changeCheckbox() {
    if (this.checked) {
      this.host.removeAttribute('checked');
    }
    else {
      this.host.setAttribute('checked', '');
    }
    this.host.removeAttribute('error');
    this.onchecked.emit({
      checked: this.checked,
      value: this.value
    });
  }
  onPressEnter(e) {
    if (e.keyCode == 13) {
      if (this.checked) {
        this.host.removeAttribute('checked');
      }
      else {
        this.host.setAttribute('checked', '');
      }
    }
  }
  /** Verificar si el checkbox se encuentra agrupado */
  groupVerification() {
    const grouper = this.host.closest('ibk-checkbox-group');
    this._grouped = grouper != null ? true : false;
  }
  onRadioFocusIn() { this._focus = true; }
  onRadioFocusOut() { this._focus = false; }
  render() {
    return (h("div", { class: this.containerClass() }, h("label", { class: "ibk-checkbox__label" }, h("input", { class: "ibk-checkbox__hidden", checked: this.checked, type: "checkbox", value: this.value }), h("span", { class: "ibk-checkbox__icon" }, h("i", { class: "ibk-checkbox__check icon-xs-check" })), h("span", { class: "ibk-checkbox__text", innerHTML: this.label })), (!this._grouped && this.error) && h("span", { class: "ibk-checkbox__error-message" }, this.requiredMessage)));
  }
  get host() { return this; }
  static get style() { return checkboxCss; }
};

const checkboxGroupCss = ".ibk-checkbox-group:not(.ibk-checkbox-group--inline) ibk-checkbox:not(:last-child){display:block;margin-bottom:10px}.ibk-checkbox-group__subtitle{margin:0 0 12px 0;font-family:var(--fontMontserrat);font-size:14px}.ibk-checkbox-group__error-message{color:var(--extendedWatermelon1);font-size:12px;font-family:var(--fontMontserrat);font-weight:500;min-height:15px;margin-top:7px;display:block}.ibk-checkbox-group--inline .ibk-checkbox-group__list{display:flex;align-items:center;flex-wrap:wrap}.ibk-checkbox-group--inline ibk-checkbox:not(:last-child){margin-right:30px}.ibk-checkbox-group--inline ibk-checkbox{display:inline-block}";

const IbkCheckboxGroup = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.oncheckedgroup = createEvent(this, "oncheckedgroup", 7);
    /** Define si los checkbox se alinearán uno al lado de otro */
    this.inline = false;
    /** Error en el checkbox group */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si todos los checkboxes se encuentra deseleccionados, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Selecciona una opción';
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-checkbox-group', [
        { inline: this.inline },
        { error: this.error }
      ]);
    };
    /** Escucha el evento al seleccionar algún checkbox dentro del gruppo */
    this.listenSlottedEvents = () => {
      const checkboxes = this.host.querySelectorAll('ibk-checkbox');
      let checked = [];
      Array.from(checkboxes, (check) => {
        checked.push({
          checked: false,
          value: check.getAttribute('value')
        });
        check.addEventListener('onchecked', (e) => {
          let current = checked.findIndex(c => c.value == e.detail.value);
          checked[current] = e.detail;
          this.oncheckedgroup.emit(checked);
          this.error = false;
          Array.from(checkboxes, (c) => c.removeAttribute('error'));
        });
        if (this.error) {
          check.setAttribute('error', '');
        }
      });
    };
  }
  componentDidLoad() {
    this.listenSlottedEvents();
  }
  render() {
    return (h("div", { class: this.containerClass() }, h("div", { class: "ibk-checkbox-group__list" }, this.subtitle && h("p", { class: "ibk-checkbox-group__subtitle" }, this.subtitle), h("slot", null)), this.error && h("span", { class: "ibk-checkbox-group__error-message" }, this.requiredMessage)));
  }
  get host() { return this; }
  static get style() { return checkboxGroupCss; }
};

const drawerCss = ".ibk-drawer{box-sizing:border-box;position:fixed;height:100%;width:100%;background-color:rgba(255, 255, 255, 0.75);cursor:pointer;top:0;left:0;opacity:0;display:none;transition:var(--slow);overflow:hidden;z-index:10}.ibk-drawer--container{top:initial;left:initial;z-index:initial}.ibk-drawer *{box-sizing:border-box}.ibk-drawer__content{padding:30px;background-color:white;position:absolute;cursor:default;transition:var(--slow)}.ibk-drawer--open-right .ibk-drawer__content{top:0;right:-100%;height:100%;width:500px;box-shadow:-2px 0 5px 0 var(--gray4)}.ibk-drawer--open-left .ibk-drawer__content{top:0;left:-100%;height:100%;width:500px;box-shadow:2px 0 5px 0 var(--gray4)}.ibk-drawer--open-top .ibk-drawer__content{top:-100%;left:0;width:100%;box-shadow:0 2px 5px 0 var(--gray4)}.ibk-drawer--open-bottom .ibk-drawer__content{bottom:-100%;left:0;width:100%;box-shadow:0 -2px 5px 0 var(--gray4)}.ibk-drawer__close{appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;background-color:transparent;border:none;position:absolute;top:20px;right:20px;font-size:24px;cursor:pointer;color:var(--grayText)}.ibk-drawer__close:active{transform:translateY(1px)}";

const IbkDrawer = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Determina la posición en donde se abrirá el contenido del drawer */
    this.position = 'right';
    /** Determina si el drawer se encuentra visible o no */
    this.show = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-drawer', [
        `open-${this.position}`,
        { container: this.container != undefined }
      ]);
    };
    this.getContainerLimits = () => {
      if (this.container != null) {
        let limits = {};
        const element = document.querySelector(this.container);
        const top = element.offsetTop;
        const left = element.offsetLeft;
        const bottom = window.innerHeight - (top + element.clientHeight);
        const right = window.innerWidth - (left + element.clientWidth);
        const height = element.clientHeight;
        const width = element.clientWidth;
        if (this.position == 'right') {
          limits.top = top + 'px';
          limits.right = right + 'px';
        }
        else if (this.position == 'bottom') {
          limits.bottom = bottom + 'px';
          limits.left = left + 'px';
        }
        else if (this.position == 'left') {
          limits.top = top + 'px';
          limits.left = left + 'px';
        }
        else if (this.position == 'top') {
          limits.top = top + 'px';
          limits.left = left + 'px';
        }
        limits.width = width + 'px';
        limits.height = height + 'px';
        return limits;
      }
    };
    /** Cierra el drawer al dar click sobre el fondo o el botón cerrar */
    this.hideDrawer = (e) => {
      const t = e.target;
      const content = t.closest('.ibk-drawer__content');
      if (content == null) {
        this.host.removeAttribute('show');
      }
    };
  }
  onShowChange(show) {
    const mask = this.host.querySelector('.ibk-drawer');
    const content = this.host.querySelector('.ibk-drawer__content');
    if (show) {
      mask.style.display = 'block';
      setTimeout(() => mask.style.opacity = '1', 10);
      setTimeout(() => {
        if (this.position == 'right') {
          content.style.right = '0';
        }
        else if (this.position == 'left') {
          content.style.left = '0';
        }
        else if (this.position == 'bottom') {
          content.style.bottom = '0';
        }
        else if (this.position == 'top') {
          content.style.top = '0';
        }
      }, 250);
    }
    else {
      if (this.position == 'right') {
        content.style.right = '-100%';
      }
      else if (this.position == 'left') {
        content.style.left = '-100%';
      }
      else if (this.position == 'bottom') {
        content.style.bottom = '-100%';
      }
      else if (this.position == 'top') {
        content.style.top = '-100%';
      }
      setTimeout(() => mask.style.opacity = '0', 250);
      setTimeout(() => mask.style.display = 'none', 500);
    }
  }
  render() {
    return (h("div", { class: this.containerClass(), onClick: this.hideDrawer, style: this.getContainerLimits() }, h("div", { class: "ibk-drawer__content", style: { backgroundColor: this.backgroundColor } }, h("button", { onClick: () => this.host.removeAttribute('show'), type: "button", class: "ibk-drawer__close icon-m-close" }), h("slot", null))));
  }
  get host() { return this; }
  static get watchers() { return {
    "show": ["onShowChange"]
  }; }
  static get style() { return drawerCss; }
};

const dropdownCss = ".ibk-dropdown{width:100%;box-sizing:border-box;position:relative;color:var(--grayText)}.ibk-dropdown *{box-sizing:border-box}.ibk-dropdown__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-dropdown__subtitle{font-family:var(--fontMontserrat);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-dropdown__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;height:48px;transition:var(--fast);overflow:hidden;background-color:white;cursor:pointer}@media screen and (max-width: 360px){.ibk-dropdown__input{height:44px}}.ibk-dropdown__input:hover{border-color:var(--gray3)}.ibk-dropdown__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;display:block;height:100%;padding:0 0 0 15px;font-family:var(--fontGeometria);font-size:16px;font-weight:500;background-color:transparent;cursor:pointer;text-overflow:ellipsis}.ibk-dropdown__value::placeholder{color:var(--gray2);font-weight:400}.ibk-dropdown__card-image{display:inline-block;width:40px;margin-left:15px}.ibk-dropdown__icon-down{padding:15px;color:var(--primaryGreen1);pointer-events:none;font-size:7px;transition:var(--fast)}.ibk-dropdown__mobile{position:relative}.ibk-dropdown__mobile .ibk-dropdown__icon-down{position:absolute;top:calc(50% - (32px / 2));right:0}.ibk-dropdown__select{display:block;height:48px;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:1px solid var(--gray4);width:100%;border-radius:4px;padding:0 15px;font-family:var(--fontGeometria);font-size:16px}.ibk-dropdown__select-option{font-size:14px}@media screen and (max-width: 360px){.ibk-dropdown__select{height:44px}}.ibk-dropdown--error .ibk-dropdown__input,.ibk-dropdown--error .ibk-dropdown__select{border-color:var(--extendedWatermelon1)}.ibk-dropdown--error.ibk-dropdown--focus .ibk-dropdown__input{box-shadow:inset 0 0 0 0.5px var(--extendedWatermelon1)}.ibk-dropdown--error .ibk-dropdown__trailing-icon,.ibk-dropdown--error .ibk-dropdown__leading-icon{color:var(--extendedWatermelon1)}.ibk-dropdown__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-dropdown--disabled{cursor:default;pointer-events:none}.ibk-dropdown--disabled .ibk-dropdown__input,.ibk-dropdown--disabled .ibk-dropdown__select{background-color:var(--gray5)}.ibk-dropdown--disabled .ibk-dropdown__icon-down{color:var(--gray2)}.ibk-dropdown--disabled .ibk-dropdown__select{color:var(--gray2)}.ibk-dropdown__dropitems{width:100%;position:absolute;top:calc(100% - 23px);border:1px solid var(--gray4);border-radius:0 0 4px 4px;display:none;z-index:1;box-shadow:0 2px 4px 0 var(--gray4);overflow:hidden;background-color:white}.ibk-dropdown__dropitems ibk-dropdown-item:last-child .ibk-dropdown-item{border-bottom:0;line-height:48px}@media screen and (max-width: 360px){.ibk-dropdown__dropitems{top:43px}.ibk-dropdown__dropitems ibk-dropdown-item:last-child .ibk-dropdown-item{line-height:44px}}.ibk-dropdown__dropitems-list{margin:0;padding:0;max-height:240px;overflow:auto}.ibk-dropdown__dropitems-list::-webkit-scrollbar{width:5px;background-color:white}.ibk-dropdown__dropitems-list::-webkit-scrollbar-thumb{background-color:var(--primaryGreen1);border-radius:3px}@media screen and (max-width: 360px){.ibk-dropdown__dropitems-list{max-height:220px}}.ibk-dropdown--open .ibk-dropdown__input{border-bottom-right-radius:0;border-bottom-left-radius:0;box-shadow:0 2px 4px 0 var(--gray4)}.ibk-dropdown--open .ibk-dropdown__dropitems{display:block}.ibk-dropdown--open .ibk-dropdown__icon-down{transform:rotate(-180deg)}.ibk-dropdown__searcher{background-color:white;display:flex;align-items:center;justify-content:space-between;padding:0 15px;border-bottom:1px solid var(--gray4)}.ibk-dropdown__searcher-value{width:100%;margin:0 10px;padding:0;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;height:47px;font-family:var(--fontGeometria);font-size:14px;font-weight:500}@media screen and (max-width: 360px){.ibk-dropdown__searcher-value{height:43px}}.ibk-dropdown__searcher-value::placeholder{color:var(--gray2);font-weight:400}.ibk-dropdown__searcher-icon{color:var(--gray2)}.ibk-dropdown__searcher-erase{color:var(--gray1);cursor:pointer}.ibk-dropdown__searcher-erase:active{transform:translateY(1px)}.ibk-dropdown__trigger{height:48px;display:flex;align-items:center;justify-content:center;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:none;background-color:transparent;cursor:pointer;transition:background-color var(--fast)}.ibk-dropdown__trigger:hover{background-color:rgba(0,0,0,0.025)}.ibk-dropdown__trigger:active{transform:translateY(1px)}.ibk-dropdown__trigger-icon{pointer-events:none;font-size:18px;color:var(--primaryGreen1)}.ibk-dropdown--trigger-round,.ibk-dropdown--trigger-box{display:inline-block;width:auto}.ibk-dropdown--trigger-round .ibk-dropdown__dropitems,.ibk-dropdown--trigger-box .ibk-dropdown__dropitems{border-top-right-radius:4px;border-top-left-radius:4px;top:100%}.ibk-dropdown--trigger-round .ibk-dropdown-item,.ibk-dropdown--trigger-box .ibk-dropdown-item{padding-right:50px}.ibk-dropdown--trigger-round .ibk-dropdown__trigger{width:48px;border-radius:50%}.ibk-dropdown--trigger-box .ibk-dropdown__trigger{border-radius:4px;padding:0 10px}.ibk-dropdown__trigger-text{color:var(--primaryGreen1);font-size:14px;font-weight:500;font-family:var(--fontGeometria)}.ibk-dropdown__trigger-space{padding-left:7px}.ibk-dropdown--no-handling-error .ibk-dropdown__dropitems{top:calc(100% - 1px)}";

const IbkDropdown = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onchange = createEvent(this, "onchange", 7);
    /** Texto de ayuda dentro del campo seleccionable del dropdown */
    this.placeholder = 'Seleccione';
    /** Se mostrará un mensaje de error */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el dropdown se encuentra vacío, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Por favor seleccione una opción';
    /** Se agregará un campo de texto al abrir el dropdown donde se podrá ingresar texto y filtrar entre los elementos del dropdown */
    this.searcher = false;
    /** Se agregará un placeholder personalizado al input de busqueda */
    this.searcherPlaceholder = 'Buscar';
    /** El dropdown no se podrá seleccionar */
    this.disabled = false;
    /** Define si el dropdown no contará con manejo de errores. Se omitirá el espacio generado para el mensaje de error */
    this.noHandlingError = false;
    /** Estado que determina si el dropdown se encuentra abierto */
    this._open = false;
    /** El dispositivo es un móvil */
    this._mobileDevice = false;
    /** Determina si el componente se está ejecutando en un dispositivo móvil */
    this.checkDeviceMobile = () => {
      if (/Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent)) {
        this._mobileDevice = true;
      }
    };
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-dropdown', [
        { error: this.error },
        { disabled: this.disabled },
        { open: this._open },
        { 'trigger-round': this.triggerIcon != undefined && this.triggerText == undefined },
        { 'trigger-box': this.triggerText != undefined },
        { 'no-handling-error': this.noHandlingError }
      ]);
    };
    /** Abre o cierra el dropdown dependiendo del estado actual */
    this.dropdownHandler = (e) => {
      e.preventDefault();
      e.stopPropagation();
      // Cerrar otros dropdowns que se encuentren abiertos
      const isOpen = this.host.querySelector('.ibk-dropdown').classList.contains('ibk-dropdown--open');
      if (!isOpen && this._open) {
        this._open = false;
      }
      setTimeout(() => {
        const dropitems = document.querySelectorAll('.ibk-dropdown__dropitems');
        Array.from(dropitems, (item) => {
          const otherContainers = item.closest('.ibk-dropdown');
          otherContainers.classList.remove('ibk-dropdown--open');
        });
        this._open = !this._open;
        if (!this._open) {
          const preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
          if (preselected != null) {
            preselected.removeAttribute('preselected');
          }
        }
        else {
          setTimeout(() => {
            this.setPreselected();
            const searcher = this.host.querySelector('.ibk-dropdown__searcher-value');
            searcher && searcher.focus();
          }, 10);
        }
      }, 10);
    };
    /** Cierra el dropdown al hacer click fuera del mismo */
    this.bodyClick = () => {
      const body = document.querySelector('body');
      body.addEventListener('click', e => {
        const t = e.target;
        const input = t.closest('.ibk-dropdown__input');
        const closest = t.closest('.ibk-dropdown__value');
        const trigger = t.closest('.ibk-dropdown__trigger');
        const searcher = t.closest('.ibk-dropdown__searcher');
        if (this._open && input == null && closest == null && searcher == null && trigger == null) {
          this._open = false;
          let preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
          if (preselected != null) {
            preselected.removeAttribute('preselected');
          }
        }
      });
    };
    /** Validar si existe algún item pre seleccionado */
    this.setPreselected = () => {
      let preselected = this.host.querySelector('ibk-dropdown-item[selected]:not([selected="false"])');
      if (preselected != null) {
        this._selectedItem = {
          value: preselected.getAttribute('value'),
          label: preselected.getAttribute('label'),
          cardType: preselected.getAttribute('card-type')
        };
        this.moveScrollToSelection(preselected, 'down');
      }
    };
    /** Escucha el evento al seleccionar algún item del dropdown */
    this.listenSlottedEvents = () => {
      const dropitems = this.host.querySelectorAll('ibk-dropdown-item');
      Array.from(dropitems, item => {
        item.addEventListener('onselect', (e) => {
          this._selectedItem = e.detail;
          Array.from(dropitems, d => {
            if (item != d) {
              d.removeAttribute('selected');
            }
          });
          this.clearSearcher();
          this.host.removeAttribute('error');
          this.onchange.emit(this._selectedItem);
          if (this._grouper != null) {
            this._grouper.removeAttribute('error');
          }
        });
      });
    };
    /** Al escribir en el buscador, filtrará entre las opciones */
    this.searchOption = (e) => {
      const t = e.target;
      const dropitems = this.host.querySelectorAll('ibk-dropdown-item');
      if (t.value != '') {
        this._cleared = true;
        Array.from(dropitems, (item) => {
          const label = item.querySelector('.ibk-dropdown-item__label');
          const plain = convertToPlainString(label.innerHTML);
          if (plain.search(t.value) < 0) {
            item.setAttribute('hidden', '');
          }
          else {
            item.removeAttribute('hidden');
          }
        });
      }
      else {
        this.showAllOptions();
      }
    };
    /** Elimina el contenido del buscador */
    this.clearSearcher = () => {
      const searcher = this.host.querySelector('.ibk-dropdown__searcher-value');
      if (searcher != null) {
        searcher.value = '';
        searcher.focus();
        this.showAllOptions();
      }
    };
    /** Muestra todas las opciones que se ocultaron al filtrar usando el buscador */
    this.showAllOptions = () => {
      const dropitems = this.host.querySelectorAll('ibk-dropdown-item');
      Array.from(dropitems, (item) => {
        item.removeAttribute('hidden');
      });
      this._cleared = false;
    };
    /** Verifica que el item preseleccionado se encuentre dentro del espacio visible del scrollbar */
    this.moveScrollToSelection = (preselected, moveTo) => {
      if (this._open) {
        const list = this.host.querySelector('.ibk-dropdown__dropitems-list');
        const itemHeight = list.querySelector('.ibk-dropdown-item').clientHeight;
        const visible = visibilityValidate(preselected, list);
        if (!visible && moveTo == 'down') {
          list.scrollTo({ top: preselected.offsetTop - (list.clientHeight) });
        }
        else if (!visible && moveTo == 'up') {
          list.scrollTo({ top: preselected.offsetTop - itemHeight });
        }
      }
    };
    /** Elimina la preseleccion al hacer focus en el buscador */
    this.deletePreselected = () => {
      const preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
      if (preselected != null) {
        preselected.removeAttribute('preselected');
      }
    };
    /** Si el dispositivo es mobile, tomará los "ibk-dropdown-items" y los convertirá en "option" */
    this.mobileOptions = () => {
      const items = this.host.querySelectorAll('ibk-dropdown-item');
      let options = [];
      Array.from(items, (it) => {
        let opt = {
          value: it.getAttribute('value'),
          label: it.getAttribute('label'),
          cardType: it.getAttribute('card-type'),
          selected: it.getAttribute('selected')
        };
        options.push(opt);
        it.remove();
      });
      return options;
    };
  }
  componentDidLoad() {
    this.bodyClick();
    this.listenSlottedEvents();
    this.checkDeviceMobile();
  }
  componentWillLoad() {
    this.setPreselected();
    this._grouper = this.host.closest('ibk-form-group');
  }
  /** Usando las flechas de navegación se preselecciona una opcion */
  optionsNavigate(e) {
    if (this._open) {
      // const dropitems = this.host.querySelectorAll('ibk-dropdown-item')
      let preselected = this.host.querySelector('ibk-dropdown-item[preselected]:not([preselected="false"])');
      const itemsLength = this.host.querySelectorAll('ibk-dropdown-item').length;
      // Flecha hacia abajo
      if (e.keyCode == 40) {
        let nextItem;
        if (preselected == null) {
          nextItem = this.host.querySelector('ibk-dropdown-item');
          nextItem = nextItem.matches('[hidden]') ? this.host.querySelector('ibk-dropdown-item:not([hidden])') : nextItem;
        }
        else {
          preselected.removeAttribute('preselected');
          nextItem = nextSibling(preselected, ':not([hidden])');
        }
        if (nextItem == null || nextItem == undefined) {
          nextItem = this.host.querySelector('ibk-dropdown-item:not([hidden])');
        }
        nextItem.setAttribute('preselected', '');
        this.moveScrollToSelection(nextItem, 'down');
      }
      // Flecha hacia arriba
      else if (e.keyCode == 38) {
        let prevItem;
        if (preselected == null) {
          prevItem = this.host.querySelectorAll('ibk-dropdown-item')[itemsLength - 1];
          prevItem = prevItem.matches('[hidden]') ? this.host.querySelectorAll('ibk-dropdown-item:not([hidden])')[itemsLength - 1] : prevItem;
        }
        else {
          preselected.removeAttribute('preselected');
          prevItem = prevSibling(preselected, ':not([hidden])');
        }
        if (prevItem == null || prevItem.classList.contains('ibk-dropdown__searcher')) {
          prevItem = this.host.querySelectorAll('ibk-dropdown-item')[itemsLength - 1];
        }
        prevItem.setAttribute('preselected', '');
        this.moveScrollToSelection(prevItem, 'up');
      }
      // Tecla enter
      else if (e.keyCode == 13) {
        this._selectedItem = {
          value: preselected.getAttribute('value'),
          label: preselected.getAttribute('label'),
          cardType: preselected.getAttribute('card-type')
        };
        const oldSelected = this.host.querySelector('[selected]');
        if (oldSelected != null) {
          oldSelected.removeAttribute('selected');
        }
        const newSelected = this.host.querySelector(`[value="${preselected.getAttribute('value')}"]`);
        newSelected.setAttribute('selected', '');
        this.clearSearcher();
        this.host.removeAttribute('error');
        this._open = false;
        this.onchange.emit(this._selectedItem);
        if (this._grouper != null) {
          this._grouper.removeAttribute('error');
        }
      }
      // Tecla Esc
      else if (e.keyCode == 27) {
        this.clearSearcher();
        this._open = false;
      }
    }
  }
  render() {
    var _a, _b, _c;
    if (!this._mobileDevice) {
      return (h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && h("span", { class: "ibk-dropdown__label" }, this.label), this.subtitle && h("span", { class: "ibk-dropdown__subtitle" }, this.subtitle), (this.triggerIcon == undefined && this.triggerText == undefined) ?
        h("label", { class: "ibk-dropdown__input", onClick: this.dropdownHandler }, h("input", { type: "hidden", value: (_a = this._selectedItem) === null || _a === void 0 ? void 0 : _a.value }), ((_b = this._selectedItem) === null || _b === void 0 ? void 0 : _b.cardType) && h("img", { class: "ibk-dropdown__card-image", src: `../assets/images/${this._selectedItem.cardType}.png`, alt: this._selectedItem.cardType }), h("input", { class: "ibk-dropdown__value", type: "text", value: (_c = this._selectedItem) === null || _c === void 0 ? void 0 : _c.label, placeholder: this.placeholder, readOnly: true }), h("i", { class: "ibk-dropdown__icon-down icon-xs-arrow-down" })) :
        h("button", { type: "button", class: "ibk-dropdown__trigger", onClick: this.dropdownHandler }, this.triggerIcon && h("i", { style: { color: this.triggerIconColor }, class: 'ibk-dropdown__trigger-icon ' + this.triggerIcon }), this.triggerText && h("span", { class: 'ibk-dropdown__trigger-text' + (this.triggerIcon && this.triggerText && ' ibk-dropdown__trigger-space') }, this.triggerText)), (this.triggerIcon == undefined && this.triggerText == undefined && !this.noHandlingError) && h("span", { class: "ibk-dropdown__error-message" }, this.error && this.requiredMessage), h("div", { class: "ibk-dropdown__dropitems" }, this.searcher &&
        h("div", { class: "ibk-dropdown__searcher" }, h("i", { class: "ibk-dropdown__searcher-icon icon-m-search" }), h("input", { class: "ibk-dropdown__searcher-value", type: "text", placeholder: this.searcherPlaceholder, onInput: this.searchOption, onFocus: this.deletePreselected }), this._cleared && h("i", { onClick: this.clearSearcher, class: "ibk-dropdown__searcher-erase icon-m-status-error" })), h("ul", { class: "ibk-dropdown__dropitems-list" }, h("slot", null)))));
    }
    else {
      return (h("div", { class: this.containerClass() }, this.label && h("span", { class: "ibk-dropdown__label" }, this.label), this.subtitle && h("span", { class: "ibk-dropdown__subtitle" }, this.subtitle), h("div", { class: "ibk-dropdown__mobile" }, h("select", { class: "ibk-dropdown__select" }, h("slot", null), this.placeholder && h("option", { disabled: true, selected: true, value: "-1" }, this.placeholder), Array.from(this.mobileOptions(), (option) => {
        return (h("option", { class: "ibk-dropdown__select-option", value: option.value, selected: option.selected != null ? true : null }, option.cardType != null ? `${firstCapitalice(option.cardType)} - ` : '', option.label));
      })), h("i", { class: "ibk-dropdown__icon-down icon-xs-arrow-down" })), h("span", { class: "ibk-dropdown__error-message" }, this.error && this.requiredMessage)));
    }
  }
  get host() { return this; }
  static get style() { return dropdownCss; }
};

const dropdownItemCss = ".ibk-dropdown-item{display:flex;align-items:center;line-height:47px;border-bottom:1px solid var(--gray4);background-color:white;padding:0 15px;cursor:pointer;transition:var(--fast);color:var(--grayText)}.ibk-dropdown-item--preselected{background-color:var(--gray5)}.ibk-dropdown-item__label{font-family:var(--fontGeometria);font-size:14px;font-weight:500;pointer-events:none;text-overflow:ellipsis;white-space:nowrap;max-width:100%;display:block;overflow:hidden}.ibk-dropdown-item__card-image{display:inline-block;width:40px;margin-right:12px}.ibk-dropdown-item--selected{background-color:var(--gray5)}.ibk-dropdown-item--selected .ibk-dropdown-item__label{color:var(--primaryGreen1)}.ibk-dropdown-item--hide{display:none}@media screen and (max-width: 360px){.ibk-dropdown-item{line-height:43px}}.ibk-dropdown-item--disabled{pointer-events:none;background-color:var(--gray5);color:var(--gray2)}";

const IbkDropdownItem = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onselect = createEvent(this, "onselect", 7);
    /** Se ocultará la opción de la lista */
    this.hide = false;
    /** Define si el item se mantendrá marcado al ser seleccionado */
    this._keepMarked = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-dropdown-item', [
        { selected: this.selected && !this._keepMarked },
        { hide: this.hide },
        { preselected: this.preselected },
        { disabled: this.disabled }
      ]);
    };
    /** Selecciona el elemento y lo envía al componente padre "ibk-dropdown" */
    this.selectItem = () => {
      this.host.setAttribute('selected', '');
      const item = {
        value: this.value,
        label: this.label,
        cardType: this.cardType
      };
      this.onselect.emit(item);
    };
  }
  componentWillLoad() {
    const keepMarkedAttr = this.host.closest('ibk-dropdown').getAttribute('keep-marked');
    if (keepMarkedAttr != undefined) {
      this._keepMarked = true;
    }
  }
  setPreselected() {
    const parent = this.host.closest('ibk-dropdown');
    const preselected = parent.querySelector('ibk-dropdown-item[preselected]');
    if (preselected != null) {
      preselected.removeAttribute('preselected');
    }
    this.host.setAttribute('preselected', '');
  }
  deletePreselected() {
    this.host.removeAttribute('preselected');
  }
  render() {
    return (h("li", { class: this.containerClass(), "data-id": this.value, onClick: this.selectItem }, this.cardType && h("img", { class: "ibk-dropdown-item__card-image", src: getAssetPath(`../assets/images/${this.cardType.toLowerCase()}.png`), alt: this.cardType }), h("span", { class: "ibk-dropdown-item__label", style: { color: this.color } }, this.label)));
  }
  get host() { return this; }
  static get style() { return dropdownItemCss; }
};

const IbkForm = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onsubmit = createEvent(this, "onsubmit", 7);
    this.submitForm = (e) => {
      e.preventDefault();
      let wrongElements = 0;
      this._formElements.forEach((element) => {
        var _a;
        if (element.tagName.toLowerCase() == 'ibk-form-group') {
          const fields = element.querySelectorAll('ibk-textfield, ibk-dropdown');
          const required = element.getAttribute('required');
          const joined = element.getAttribute('joined');
          let empty = false;
          fields.forEach((field) => {
            if (required != null) {
              field.setAttribute('required', '');
            }
            if (joined != null) {
              if (field.tagName.toLowerCase() == 'ibk-textfield') {
                const value = field.querySelector('.ibk-textfield__value').value;
                if (value == '') {
                  empty = true;
                }
              }
              else if (field.tagName.toLowerCase() == 'ibk-dropdown') {
                const value = field.querySelector('.ibk-dropdown__value').value;
                if (value == '') {
                  empty = true;
                }
              }
            }
          });
          if (empty && required != null) {
            element.setAttribute('error', '');
          }
        }
        if (element.tagName.toLowerCase() == 'ibk-textfield') {
          const required = element.getAttribute('required');
          const type = (_a = element.getAttribute('type')) !== null && _a !== void 0 ? _a : 'text';
          const value = element.querySelector('.ibk-textfield__value').value;
          let regex;
          if (required != null && value == '') {
            element.setAttribute('error', '');
            wrongElements++;
          }
          else {
            switch (type) {
              case 'dni':
                regex = regexValidators.dni;
                break;
              case 'document':
                regex = regexValidators.document;
                break;
              case 'email':
                regex = regexValidators.email;
                break;
              case 'number':
                regex = regexValidators.numberFormat;
                break;
              case 'expiration':
                regex = regexValidators.expiration;
                break;
              case 'cvv':
                regex = regexValidators.cvv;
                break;
              case 'phone':
                regex = regexValidators.number;
                break;
            }
            if (value != '' && regex != undefined && !regex.test(value)) {
              element.setAttribute('error', '');
              wrongElements++;
            }
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-dropdown') {
          const required = element.getAttribute('required');
          const value = element.querySelector('.ibk-dropdown__value').value;
          if (required != null && value == '') {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-checkbox') {
          const required = element.getAttribute('required');
          const checked = element.getAttribute('checked');
          const grouper = element.closest('ibk-checkbox-group');
          if (required != null && checked == null && grouper == null) {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-checkbox-group') {
          const required = element.getAttribute('required');
          const checked = element.querySelectorAll('ibk-checkbox[checked]');
          if (required != null && checked.length == 0) {
            element.setAttribute('error', '');
            Array.from(element.querySelectorAll('ibk-checkbox'), (checkbox) => checkbox.setAttribute('error', ''));
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-radio') {
          const required = element.getAttribute('required');
          const selected = element.getAttribute('selected');
          const grouper = element.closest('ibk-radio-group');
          if (required != null && selected == null && grouper == null) {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-radio-group') {
          const required = element.getAttribute('required');
          const selected = element.querySelector('ibk-radio[selected]');
          if (required != null && selected == null) {
            element.setAttribute('error', '');
            Array.from(element.querySelectorAll('ibk-radio'), (radio) => radio.setAttribute('error', ''));
            wrongElements++;
          }
        }
        else if (element.tagName.toLowerCase() == 'ibk-calendar') {
          const required = element.getAttribute('required');
          const value = element.querySelector('.ibk-calendar__input').value;
          const multiselect = element.getAttribute('multiselect');
          let error = false;
          if (multiselect != null) {
            const splitted = value.split('-');
            if (splitted.length == 1 || (splitted.length == 2 && splitted[1].trim() == '')) {
              error = true;
            }
          }
          else {
            if (value == '') {
              error = true;
            }
          }
          if (required != null && error) {
            element.setAttribute('error', '');
            wrongElements++;
          }
        }
      });
      this.onsubmit.emit(wrongElements == 0);
    };
  }
  componentDidLoad() {
    this._formElements = this.host.querySelectorAll('ibk-textfield, ibk-form-group, ibk-dropdown, ibk-checkbox, ibk-checkbox-group, ibk-radio, ibk-radio-group, ibk-calendar');
  }
  render() {
    return (h("form", { class: "ibk-form", onSubmit: (e) => this.submitForm(e) }, h("slot", null)));
  }
  get host() { return this; }
  static get style() { return {
    0: ".ibk-form { display: block; }"
  }; }
};

const formGroupCss = ".ibk-form-group{box-sizing:border-box}.ibk-form-group *{box-sizing:border-box}.ibk-form-group__label{color:var(--gray1);font-size:14px;font-family:var(--fontGeometria);font-weight:500;margin-bottom:7px;display:block}.ibk-form-group__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-form-group__list{display:flex;align-items:flex-start;justify-content:space-between}.ibk-form-group ibk-textfield,.ibk-form-group ibk-dropdown{width:100%}.ibk-form-group:not(.ibk-form-group--joined) ibk-textfield:not(:last-child),.ibk-form-group:not(.ibk-form-group--joined) ibk-dropdown:not(:last-child){margin-right:15px}.ibk-form-group__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-form-group--joined .ibk-textfield__input,.ibk-form-group--joined .ibk-dropdown__input{border-radius:0}.ibk-form-group--joined ibk-textfield:first-child .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:first-child .ibk-dropdown__input{border-radius:4px 0 0 4px;position:relative}.ibk-form-group--joined ibk-textfield:not(:last-child) .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:not(:last-child) .ibk-dropdown__input{border-right:0}.ibk-form-group--joined ibk-textfield:last-child .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:last-child .ibk-dropdown__input{border-radius:0 4px 4px 0}.ibk-form-group--joined ibk-textfield:not(:last-child):hover+ibk-textfield .ibk-textfield__input,.ibk-form-group--joined ibk-textfield:not(:last-child):hover+ibk-dropdown .ibk-dropdown__input,.ibk-form-group--joined ibk-dropdown:not(:last-child):hover+ibk-textfield .ibk-textfield__input,.ibk-form-group--joined ibk-dropdown:not(:last-child):hover+ibk-dropdown .ibk-dropdown__input{border-left:1px solid var(--gray3)}";

const IbkFormGroup = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Define si los campos se encontrarán unidos, sin espaceios entre si */
    this.joined = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = "Los campos son requeridos";
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-form-group', [
        { joined: this.joined }
      ]);
    };
    this.setFocus = () => {
      this._allFields.forEach((field) => {
        field.addEventListener('onfocus', (e) => {
          var _a;
          const next = (_a = field.nextElementSibling) === null || _a === void 0 ? void 0 : _a.querySelector('.ibk-textfield__input, .ibk-dropdown__input');
          if (next && field.getAttribute('error') == null) {
            if (e.detail == 'in') {
              next.style.borderLeft = '1px solid #05be50';
            }
            else if (e.detail == 'out') {
              next.removeAttribute('style');
            }
          }
        });
      });
    };
    /** Elimina los contenedores de los mensajes de error de los campos en el grupo */
    this.configFieldProperties = () => {
      var _a;
      const _fieldsWidth = (_a = this.fieldsWidth) === null || _a === void 0 ? void 0 : _a.split(',');
      this._allFields.forEach((field, index) => {
        if (_fieldsWidth && _fieldsWidth[index]) {
          field.style.width = `${_fieldsWidth[index]}%`;
        }
        if (this.error) {
          field.setAttribute('error', '');
        }
        else {
          field.removeAttribute('error');
        }
        if (this.joined) {
          field.setAttribute('no-handling-error', '');
        }
        else {
          if (this.required) {
            field.setAttribute('required', '');
          }
          else {
            field.removeAttribute('error');
          }
        }
      });
    };
  }
  componentWillLoad() {
    this._allFields = this.host.querySelectorAll('ibk-textfield, ibk-dropdown');
    this.setFocus();
    this.configFieldProperties();
  }
  watchingError() {
    this.configFieldProperties();
  }
  render() {
    return (h("div", { class: this.containerClass() }, this.label && h("span", { class: "ibk-form-group__label" }, this.label), this.subtitle && h("span", { class: "ibk-form-group__subtitle" }, this.subtitle), h("div", { class: "ibk-form-group__list" }, h("slot", null)), this.joined && h("span", { class: "ibk-form-group__error-message" }, this.error && this.requiredMessage)));
  }
  get host() { return this; }
  static get watchers() { return {
    "error": ["watchingError"]
  }; }
  static get style() { return formGroupCss; }
};

const modalCss = ".ibk-modal{position:fixed;top:0;left:0;width:100%;min-height:100vh;height:100%;overflow:auto;box-sizing:border-box;padding:5vh 0;display:flex;align-items:center;justify-content:center}.ibk-modal *{box-sizing:border-box}.ibk-modal--light{background-color:rgba(255, 255, 255, 0.5)}.ibk-modal--dark{background-color:rgba(0, 0, 0, 0.5)}.ibk-modal__content{display:block;width:480px;padding:52px 32px;background-color:white;border-radius:5px;position:relative}.ibk-modal__close{position:absolute;top:20px;right:20px;font-size:26px;cursor:pointer;transition:color var(--fast)}.ibk-modal__close:hover{color:var(--gray1)}.ibk-modal__close:active{transform:translateY(1px)}.ibk-modal__heading{display:block;font-family:var(--fontGeometria);font-size:32px;font-weight:600;letter-spacing:-1px;margin:0 0 15px 0;line-height:36px}.ibk-modal__subtitle{display:block;font-family:var(--fontMontserrat);font-size:16px;line-height:22px;letter-spacing:-0.1px}";

const IbkModal = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Determina el color de fondo del modal */
    this.background = 'dark';
    /** Determina si el modal tendrá una "X" para cerrar el modal */
    this.fixed = false;
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-modal', [
      this.background
    ]);
  }
  render() {
    return (h("div", { class: this.containerClass() }, h("div", { class: "ibk-modal__content" }, !this.fixed && h("i", { class: "ibk-modal__close icon-m-close" }), this.heading && h("p", { class: "ibk-modal__heading" }, this.heading), this.subtitle && h("p", { class: "ibk-modal__subtitle" }, this.subtitle), h("slot", null))));
  }
  static get style() { return modalCss; }
};

const notificationCss = ".ibk-notification{padding:17px 20px;border-radius:4px;width:100%;display:none;box-sizing:border-box}.ibk-notification *{box-sizing:border-box}.ibk-notification__icon{margin-right:10px;font-size:20px}.ibk-notification__message{font-family:var(--fontMontserrat);font-size:14px;font-weight:500;line-height:20px;color:var(--grayText)}.ibk-notification--success{background-color:var(--primaryGreen5)}.ibk-notification--success .ibk-notification__icon{color:var(--primaryGreen1)}.ibk-notification--alert{background-color:var(--extendedYellow5)}.ibk-notification--alert .ibk-notification__icon{color:var(--extendedYellow1)}.ibk-notification--error{background-color:var(--extendedWatermelon5)}.ibk-notification--error .ibk-notification__icon{color:var(--extendedWatermelon1)}.ibk-notification--info{background-color:var(--extendedLightBlue5)}.ibk-notification--info .ibk-notification__icon{color:var(--extendedLightBlue1)}.ibk-notification--container-off{background-color:transparent;padding:0}.ibk-notification--auto{width:auto;padding-right:50px}.ibk-notification--show:not(.ibk-notification--auto){display:flex}.ibk-notification--show.ibk-notification--auto{display:inline-flex}.ibk-notification--fixed{position:fixed;top:0;left:0;width:100%;border-radius:0}";

const IbkNotification = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Define el tipo de notificación a mostrar<br>
     * <strong>success: </strong>Color verde<br>
     * <strong>error: </strong>Color rojo<br>
     * <strong>alert: </strong>Color amarillo<br>
     * <strong>info: </strong>Color celeste
     */
    this.type = 'success';
    /** Define si se muestra la notificación en un contenedor */
    this.container = 'on';
    /** Define el ancho de la notificación */
    this.width = 'full';
    /** Define si la notificación se mantendrá oculta */
    this.show = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-notification', [
        this.type,
        { 'container-off': this.container == 'off' },
        { auto: this.width == 'auto' },
        { show: this.show },
        { fixed: this.fixed }
      ]);
    };
  }
  watchingShowProp(show) {
    if (show && this.timeout) {
      setTimeout(() => this.host.removeAttribute('show'), this.timeout);
    }
  }
  componentWillLoad() {
    if (this.show && this.timeout) {
      setTimeout(() => this.host.removeAttribute('show'), this.timeout);
    }
  }
  render() {
    return (h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, h("i", { class: 'ibk-notification__icon icon-m-status-' + this.type }), h("span", { class: "ibk-notification__message" }, this.message)));
  }
  get host() { return this; }
  static get watchers() { return {
    "show": ["watchingShowProp"]
  }; }
  static get style() { return notificationCss; }
};

const numberPickerCss = ".ibk-number-picker{display:inline-flex;align-items:normal;box-sizing:border-box;border:1px solid var(--gray4);border-radius:4px;overflow:hidden}.ibk-number-picker *{box-sizing:border-box}.ibk-number-picker__input{height:46px;appearance:none;-webkit-appearance:none;-moz-appearance:none;background-color:transparent;outline:none;border:solid var(--gray4);border-width:0 1px 0 1px;padding:0 15px;text-align:center;font-family:var(--fontGeometria);font-weight:500;font-size:16px}.ibk-number-picker__input:read-only{cursor:default}.ibk-number-picker__button{width:46px;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;background-color:transparent;border:none;font-size:20px;color:var(--primaryGreen1);display:flex;align-items:center;justify-content:center;cursor:pointer;transition:var(--fast)}.ibk-number-picker__button--disabled{pointer-events:none;background-color:var(--gray5);color:var(--gray3)}.ibk-number-picker__button:hover{background-color:var(--gray5)}.ibk-number-picker__button:active .ibk-number-picker__button-icon{transform:translateY(1px)}.ibk-number-picker--medium .ibk-number-picker__input{width:70px}.ibk-number-picker--large .ibk-number-picker__input{width:140px}.ibk-number-picker--full{width:100%}.ibk-number-picker--full .ibk-number-picker__input{width:100%}";

const IbkNumberPicker = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onchange = createEvent(this, "onchange", 7);
    /** Define el tamaño del selector<br>
     * <strong>Medium: </strong>el ancho será para un número de dos dígitos<br>
     * <strong>Large: </strong>el ancho será para un número de hasta 8 dígitos<br>
     * <strong>Full: </strong>ocupará el 100% del ancho disponible
     */
    this.size = 'medium';
    /** Determina el número máximo del selector, por defecto será 100,000 */
    this.max = 10;
    /** Determina el número mínimo del selector, por defecto será 0 */
    this.min = 0;
    /** Determina si el número se puede editar manualmente, por defecto solo se usarán los ícono de más y menos */
    this.editable = false;
    /** Define la cantidad de números que se agregarán o quitarán a al valor actual */
    this._bounce = 1;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-number-picker', [this.size]);
    };
    /** Define de cuánto en cuánto cambiará el número al dar click en los botones más o menos */
    this.setBounce = () => {
      if (this._action == 'add') {
        if (this.current >= 0 && this.current < 20) {
          this._bounce = 1;
        }
        else if (this.current >= 20 && this.current < 999) {
          this._bounce = 10;
        }
        else if (this.current >= 100 && this.current < 9999) {
          this._bounce = 100;
        }
        else {
          this._bounce = 1000;
        }
      }
      else {
        if (this.current >= 0 && this.current <= 20) {
          this._bounce = 1;
        }
        else if (this.current > 20 && this.current <= 1000) {
          this._bounce = 10;
        }
        else if (this.current > 100 && this.current <= 10000) {
          this._bounce = 100;
        }
        else {
          this._bounce = 1000;
        }
      }
    };
    /** Acción cuando se da click sobre los botones más o menos */
    this.changeQuantity = (action) => {
      this._action = action;
      if (this._action == 'add') {
        this.current += this._bounce;
        if (this.current > this.max) {
          this.current = this.max;
        }
      }
      else {
        this.current -= this._bounce;
        if (this.current < this.min) {
          this.current = this.min;
        }
      }
      this.setBounce();
      this._currentFormated = numberFormat(this.current);
      this.onchange.emit({
        number: this.current,
        formated: this._currentFormated
      });
    };
    /** Se ejecutá cuando el usuario digita manualmente el número en el calendario */
    this.typeNumber = (e) => {
      const t = e.target;
      if (t.value == '') {
        this.current = this.min;
      }
      else {
        this.current = parseInt(t.value.replace(/,/, ''));
        this.current = (isNaN(this.current) || t.value == '') ? 0 : this.current;
        if (this.current <= this.min) {
          this.current = this.min;
        }
        else if (this.current >= this.max) {
          this.current = this.max;
        }
      }
      this._currentFormated = numberFormat(this.current);
      const input = this.host.querySelector('.ibk-number-picker__input');
      input.value = this._currentFormated;
      this.setBounce();
      this.onchange.emit({
        number: this.current,
        formated: this._currentFormated
      });
    };
  }
  componentWillLoad() {
    var _a;
    this.current = (_a = this.current) !== null && _a !== void 0 ? _a : this.max;
    this._currentFormated = numberFormat(this.current);
    this.setBounce();
  }
  render() {
    return (h("div", { class: this.containerClass() }, h("button", { type: "button", class: 'ibk-number-picker__button' + (this.current <= this.min ? ' ibk-number-picker__button--disabled' : ''), onClick: () => this.changeQuantity('remove') }, h("i", { class: "ibk-number-picker__button-icon icon-xs-minus" })), h("input", { type: "text", class: "ibk-number-picker__input", value: this._currentFormated, readOnly: !this.editable, onInput: this.typeNumber }), h("button", { type: "button", class: 'ibk-number-picker__button' + (this.current >= this.max ? ' ibk-number-picker__button--disabled' : ''), onClick: () => this.changeQuantity('add') }, h("i", { class: "ibk-number-picker__button-icon icon-xs-plus" }))));
  }
  get host() { return this; }
  static get style() { return numberPickerCss; }
};

const radioCss = ".ibk-radio{padding:5px 0}.ibk-radio *{box-sizing:border-box}.ibk-radio__hidden{display:none}.ibk-radio__label{display:inline-flex;align-items:center;color:var(--grayText);cursor:pointer}.ibk-radio__icon{display:inline-flex;align-items:center;justify-content:center;min-height:18px;min-width:18px;border:2px solid var(--gray4);border-radius:50%;margin-right:7px;transition:var(--fast)}.ibk-radio__dot{display:block;height:10px;width:10px;border-radius:50%;background-color:var(--primaryGreen1);transform:scale(0);transition:var(--fast)}.ibk-radio__label:active{transform:translateY(1px)}.ibk-radio__text{font-family:var(--fontGeometria);font-size:14px;font-weight:500}.ibk-radio__text a{text-decoration:none;color:var(--primaryGreen1)}.ibk-radio__error-message{color:var(--extendedWatermelon1);font-size:12px;font-family:var(--fontMontserrat);font-weight:500;min-height:15px;margin-top:7px;display:block}.ibk-radio--selected .ibk-radio__icon{border-color:var(--primaryGreen1)}.ibk-radio--selected .ibk-radio__dot{transform:scale(1)}.ibk-radio--disabled{pointer-events:none}.ibk-radio--disabled .ibk-radio__icon{background-color:var(--gray4);border-color:var(--gray2)}.ibk-radio--error .ibk-radio__icon{border-color:var(--extendedWatermelon1)}.ibk-radio--right .ibk-radio__label{justify-content:space-between}.ibk-radio--right .ibk-radio__icon{margin-right:0;margin-left:7px;order:2}.ibk-radio--outline .ibk-radio__label{border:1px solid var(--gray4);border-radius:4px;padding:10px}.ibk-radio--full .ibk-radio__label{width:100%}.ibk-radio--focus .ibk-radio__icon{border-color:var(--primaryGreen1)}";

const IbkRadio = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onselect = createEvent(this, "onselect", 7);
    /** Estado activo del radio */
    this.selected = false;
    /** Estado inactivo del radio */
    this.disabled = false;
    /** Error en el radio */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el radio se encuentra deseleccionado, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Este campo es requerido';
    /** Determina la posición del ícono */
    this.iconPosition = 'left';
    /** El radio se verá envuelto en una caja */
    this.outline = false;
    /** Determina si el radio ocupa el 100% de la pantalla */
    this.full = false;
    /** El radio estará agrupado en "ibk-radio-group" */
    this._grouped = false;
    /** Estado focus del radio */
    this._focus = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-radio', [
        this.iconPosition,
        { outline: this.outline },
        { selected: this.selected },
        { disabled: this.disabled },
        { error: this.error },
        { full: this.full },
        { focus: this._focus }
      ]);
    };
  }
  componentWillLoad() {
    this.groupVerification();
  }
  changeRadio() {
    this.host.setAttribute('selected', '');
    this.host.removeAttribute('error');
    this.onselect.emit({
      selected: this.selected,
      value: this.value
    });
  }
  /** Verificar si el checkbox se encuentra agrupado */
  groupVerification() {
    const grouper = this.host.closest('ibk-radio-group');
    this._grouped = grouper != null ? true : false;
  }
  onRadioFocusIn() { this._focus = true; }
  onRadioFocusOut() { this._focus = false; }
  render() {
    return (h("div", { class: this.containerClass() }, h("label", { class: "ibk-radio__label" }, h("input", { class: "ibk-radio__hidden", checked: this.selected, type: "radio", value: this.value }), h("span", { class: "ibk-radio__icon" }, h("i", { class: "ibk-radio__dot" })), h("span", { class: "ibk-radio__text", innerHTML: this.label })), (!this._grouped && this.error) && h("span", { class: "ibk-radio__error-message" }, this.requiredMessage)));
  }
  get host() { return this; }
  static get style() { return radioCss; }
};

const radioGroupCss = ".ibk-radio-group:not(.ibk-radio-group--inline) ibk-radio:not(:last-child){display:block;margin-bottom:10px}.ibk-radio-group__subtitle{margin:0 0 12px 0;font-family:var(--fontMontserrat);font-size:14px}.ibk-radio-group__error-message{color:var(--extendedWatermelon1);font-size:12px;font-family:var(--fontMontserrat);font-weight:500;min-height:15px;margin-top:7px;display:block}.ibk-radio-group--inline .ibk-radio-group__list{display:flex;align-items:center;flex-wrap:wrap}.ibk-radio-group--inline ibk-radio:not(:last-child){margin-right:30px}.ibk-radio-group--inline ibk-radio{display:inline-block}";

const IbkRadioGroup = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onchange = createEvent(this, "onchange", 7);
    /** Define si los radio se alinearán uno al lado de otro */
    this.inline = false;
    /** Error en el radio group */
    this.error = false;
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si todos los radios se encuentra deseleccionados, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Selecciona una opción';
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-radio-group', [
        { inline: this.inline },
        { error: this.error }
      ]);
    };
    /** Escucha el evento al seleccionar algún radio dentro del gruppo */
    this.listenSlottedEvents = () => {
      const radios = this.host.querySelectorAll('ibk-radio');
      Array.from(radios, (radio) => {
        radio.addEventListener('onselect', (e) => {
          this.onchange.emit(e.detail);
          this.error = false;
          Array.from(radios, (c) => {
            const value = c.getAttribute('value');
            console.log(value);
            if (value != e.detail.value) {
              c.removeAttribute('selected');
            }
            c.removeAttribute('error');
          });
        });
        if (this.error) {
          radio.setAttribute('error', '');
        }
      });
    };
  }
  componentDidLoad() {
    this.listenSlottedEvents();
  }
  render() {
    return (h("div", { class: this.containerClass() }, h("div", { class: "ibk-radio-group__list" }, this.subtitle && h("p", { class: "ibk-radio-group__subtitle" }, this.subtitle), h("slot", null)), this.error && h("span", { class: "ibk-radio-group__error-message" }, this.requiredMessage)));
  }
  get host() { return this; }
  static get style() { return radioGroupCss; }
};

const searchResultCss = ".ibk-search-result{box-sizing:border-box;display:block;width:100%;text-decoration:none;cursor:pointer;line-height:47px;padding:0 15px;font-size:14px;font-family:var(--fontGeometria);font-weight:500;transition:var(--fast);color:var(--grayText);overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.ibk-search-result *{box-sizing:border-box}.ibk-search-result--over{background-color:var(--gray5)}.ibk-search-result__match{color:var(--primaryGreen1);font-weight:500;font-family:var(--fontGeometria)}";

const IbkSearchResult = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onclick = createEvent(this, "onclick", 7);
    /** Determina si el enlace se abre en una nueva ventana o en la misma */
    this.hrefTarget = '_self';
    /** Determina si el resultado se encuentra preseleccionado */
    this.over = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-search-result', [{ over: this.over }]);
    };
    /** Envía al contenedor (ibk-searchbar) un objeto con los datos del resultado */
    this.chooseResult = () => {
      const result = {
        value: this.value,
        label: this.label,
        text: this.host.textContent,
        href: this.href,
        hrefTarget: this.hrefTarget
      };
      this.onclick.emit(result);
    };
  }
  mouseOver() { this.host.setAttribute('over', ''); }
  mouseLeave() { this.host.removeAttribute('over'); }
  render() {
    return (h("a", { class: this.containerClass(), href: this.href, target: this.hrefTarget, "data-value": this.value, onClick: this.chooseResult, innerHTML: this.label }));
  }
  get host() { return this; }
  static get style() { return searchResultCss; }
};

const searchbarCss = ".ibk-searchbar{box-sizing:border-box;color:var(--grayText);position:relative}.ibk-searchbar *{box-sizing:border-box}.ibk-searchbar__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-searchbar__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-searchbar__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;background-color:white;transition:var(--fast);cursor:text}.ibk-searchbar__input:hover{border-color:var(--gray3)}.ibk-searchbar__icon-search{color:var(--grayText);font-size:20px;display:flex;height:46px;min-width:46px;cursor:text;align-items:center;justify-content:center}.ibk-searchbar__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;outline:none;border:none;height:46px;background-color:transparent;font-family:var(--fontGeometria);font-weight:500;font-size:16px;color:var(--grayText)}.ibk-searchbar__icon-clear{min-width:46px;cursor:pointer;color:var(--gray1);text-align:center}.ibk-searchbar__icon-clear:active{transform:translateY(1px)}.ibk-searchbar__value::placeholder{color:var(--gray2);font-weight:400}.ibk-searchbar--focus .ibk-searchbar__input{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-searchbar--disabled .ibk-searchbar__input{pointer-events:none;background-color:var(--gray5)}.ibk-searchbar__results{position:absolute;width:100%;background-color:white;border:1px solid var(--gray4);top:calc(100% - 1px);border-radius:0 0 4px 4px;transition:var(--fast);display:none;box-shadow:0 2px 4px 0 var(--gray4);z-index:10}ibk-search-result:not(:last-child) .ibk-search-result{border-bottom:1px solid var(--gray4)}.ibk-searchbar--open .ibk-searchbar__input{border-radius:4px 4px 0 0}.ibk-searchbar--open .ibk-searchbar__results{display:block}.ibk-searchbar--open.ibk-searchbar--focus .ibk-searchbar__results{border-top-color:var(--primaryGreen1)}.ibk-searchbar__loading{display:flex;align-items:center;padding:15px;height:47px}.ibk-searchbar__empty-message{font-family:var(--fontGeometria);font-size:14px;color:var(--gray1);font-weight:500;height:47px;padding:15px;margin:0}.ibk-searchbar__shopstar{display:flex;align-items:center;justify-content:space-between;padding:5px 15px 15px}.ibk-searchbar__shopstar-text{font-family:var(--fontGeometria);font-size:14px}.ibk-searchbar__shopstar-img{width:90px;margin-bottom:-3.5px}.ibk-searchbar__shopstar-btn .ibk-button{margin-left:50px;min-width:180px}@media screen and (max-width: 600px){.ibk-searchbar__shopstar-btn .ibk-button{min-width:120px}}@media screen and (max-width: 400px){.ibk-searchbar__shopstar{flex-direction:column;align-items:flex-start}.ibk-searchbar__shopstar-btn .ibk-button{margin-left:0}}.ibk-searchbar__loading-icon{display:inline-block;width:20px;height:20px;border:2px solid var(--primaryGreen1);border-radius:50%;animation:ibk-searchbar-loader 500ms linear infinite;pointer-events:none;border-top-color:var(--primaryGreen4);border-left-color:var(--primaryGreen4);border-right-color:var(--primaryGreen4);margin-right:10px}@keyframes ibk-searchbar-loader{0%{transform:rotate(0deg)}0%{transform:rotate(-360deg)}}.ibk-searchbar__loading-text{font-size:14px;font-weight:500;font-family:var(--fontGeometria)}.ibk-searchbar--icon-right .ibk-searchbar__value,.ibk-searchbar--boxed.ibk-searchbar--icon-left .ibk-searchbar__value{padding-left:15px}.ibk-searchbar--icon-right:not(.ibk-searchbar--boxed) .ibk-searchbar__icon-clear{min-width:unset}.ibk-searchbar--boxed .ibk-searchbar__input{border-color:var(--primaryGreen1)}.ibk-searchbar--boxed .ibk-searchbar__icon-search{background-color:var(--primaryGreen1);color:white}.ibk-searchbar__benefit{padding:15px}.ibk-searchbar__benefit-label{font-family:var(--fontGeometria);font-size:14px;font-weight:500;margin-top:5px;margin-bottom:0}.ibk-searchbar__benefit-links ibk-button{margin-top:10px;display:inline-block}.ibk-searchbar__benefit-links ibk-button:not(:last-child){margin-right:10px}.ibk-searchbar__benefit-links .ibk-button__icon{margin-left:3px;font-size:10px}.ibk-searchbar__benefit:not(:last-child){border-bottom:1px solid var(--gray4)}";

const IbkSearchbar = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onsearch = createEvent(this, "onsearch", 7);
    this.onedit = createEvent(this, "onedit", 7);
    this.onselect = createEvent(this, "onselect", 7);
    this.onbenefitclick = createEvent(this, "onbenefitclick", 7);
    /** Texto de ayuda dentro del searchbar */
    this.placeholder = 'Buscar';
    /** Define un valor predeterminado para el searchbar */
    this.value = '';
    /** Define si el searchbar muestra un icono de carga mientras se hace la consulta */
    this.loading = false;
    /** Define si el buscador no encontró resultados */
    this.empty = false;
    /** Define si el ícono de la lupa se mostrará a la izquierda o derecha */
    this.iconPosition = 'left';
    /** El buscador mostrará los módulos de la web de Interbank Benefit */
    this.benefit = false;
    /** Si el buscador pertenece a Interbank Benefit y no se encuentran resultados, se mostrará la opción de redirigir a Shopstar */
    this.shopstarRedirect = false;
    /** Almacena el estado del cuadro de resultados, cuando está abierto o cerrado */
    this._open = false;
    /** Estado activo o inactivo del searchbar */
    this._focus = false;
    /** Define cuando los resultados de búsqueda han sido encontrados y estan listos para ser procesados */
    this._readyData = false;
    /** Almacena todos los resultados de la búsqueda en un objeto */
    this._resultData = new Array();
    /** Almacena la información filtrada en base a los criterios de búsqueda */
    this._filteredData = new Array();
    /** Navega entre los resultados al usar las flechas del teclado */
    this.navigate = (keyCode) => {
      let overedIndex = Array.from(this._htmlResults).findIndex((html) => html.getAttribute('over') != undefined);
      if (keyCode == 40) {
        overedIndex++;
        if (overedIndex >= this._htmlResults.length) {
          overedIndex = 0;
        }
      }
      else if (keyCode == 38) {
        overedIndex--;
        if (overedIndex < 0) {
          overedIndex = this._htmlResults.length - 1;
        }
      }
      if (overedIndex >= 0) {
        this._htmlResults[overedIndex].setAttribute('over', '');
        this._htmlResults.forEach((html, index) => {
          if (index != overedIndex) {
            html.removeAttribute('over');
          }
        });
      }
      if (keyCode == 13) {
        const selected = this._htmlResults[overedIndex];
        let result = {};
        if (selected) {
          result = {
            value: selected.getAttribute('value'),
            label: selected.getAttribute('label'),
            text: selected.textContent,
            href: selected.getAttribute('href'),
            hrefTarget: selected.getAttribute('href-target')
          };
        }
        else {
          result = {
            value: 'all',
            label: this.value
          };
        }
        this.onselect.emit(result);
        setTimeout(() => {
          this.host.querySelector('.ibk-searchbar__value').blur();
          this._open = false;
        }, 200);
      }
    };
    /** Escucha el evento click sobre alguno de los resultados */
    this.listenResultClick = () => {
      this._htmlResults.forEach((html) => {
        html.addEventListener('onclick', (e) => this.onselect.emit(e.detail));
      });
    };
    /** Función que se ejecuta al escribir en el searchbar */
    this.search = e => {
      const t = e.target;
      this.value = t.value;
      this._htmlResults = this.host.querySelectorAll('ibk-search-result');
      if (this.value.length <= 2 && this._htmlResults.length > 0) {
        Array.from(this._htmlResults, (result) => result.remove());
      }
      if (this.value.length == 3) {
        this._open = true;
        if (this.value != this._lastSearched) {
          this.onsearch.emit({ value: this.value, benefitModule: this._benefitModule });
          Array.from(this._htmlResults, (result) => result.remove());
          this._lastSearched = this.value;
          this.host.setAttribute('loading', '');
          this.createObjectFromResult();
        }
        else {
          this.updateResults();
        }
      }
      if (this.value.length > 3) {
        this.updateResults();
      }
    };
    this.observerCallback = () => {
      this._htmlResults = this.host.querySelectorAll('ibk-search-result');
      this._htmlResults.forEach((result, index) => {
        const data = {
          index,
          value: result.getAttribute('value'),
          label: result.getAttribute('label'),
          parsedLabel: result.getAttribute('label'),
          href: result.getAttribute('href'),
          hrefTarget: result.getAttribute('href-target')
        };
        this._resultData.push(data);
        if (this._resultData.length == 0) {
          this.empty = true;
        }
        else {
          this.empty = false;
        }
      });
      if (this._htmlResults.length > 0) {
        this.host.removeAttribute('loading');
        this.listenResultClick();
        this.updateResults();
        this._observer.disconnect();
      }
    };
    /** Agrega a un objeto global cada resultado encontrado en base a los 3 primeros caracteres */
    this.createObjectFromResult = () => {
      this._resultData = new Array();
      this._observer = new MutationObserver(this.observerCallback);
      this._observer.observe(this.host, { attributes: true, childList: true });
      this._observer.observe(this.host.querySelector('.ibk-searchbar__results'), { attributes: true, childList: true });
    };
    /** Actualiza el objeto mientras el usuario ingresa más de 3 caracteres */
    this.updateResults = () => {
      this._filteredData = new Array();
      const search = this.value.trim().split(' ');
      const orMatch = [];
      const andMatch = [];
      const exactlyMatch = [];
      this._resultData.forEach((data) => {
        const result = data.label.trim().split(' ');
        let fullMatch = false;
        let match = false;
        let exactly = false;
        let wordsMatch = [];
        if (convertToPlainString(data.label).search(convertToPlainString(this.value)) >= 0) {
          exactly = true;
        }
        search.forEach((src, index) => {
          const plainSearch = convertToPlainString(src);
          let found = false;
          result.forEach((res) => {
            const plainResult = convertToPlainString(res);
            if (plainResult.search(plainSearch) >= 0) {
              found = true;
              match = true;
              const added = wordsMatch.findIndex(w => w.text == res);
              if (added < 0) {
                wordsMatch.push({
                  text: res,
                  start: plainResult.search(plainSearch),
                  end: plainResult.search(plainSearch) + plainSearch.length,
                  match: true
                });
              }
              else {
                wordsMatch[added].match = true;
                wordsMatch[added].start = plainResult.search(plainSearch);
                wordsMatch[added].end = plainResult.search(plainSearch) + plainSearch.length;
              }
            }
            else {
              const added = wordsMatch.find(w => w.text == res);
              if (!added) {
                wordsMatch.push({
                  text: res,
                  start: plainResult.search(plainSearch),
                  end: plainResult.search(plainSearch) + plainSearch.length,
                  match: false
                });
              }
            }
          });
          if (index == 0) {
            if (found) {
              fullMatch = true;
            }
          }
          else {
            if (fullMatch && found) {
              fullMatch = true;
            }
            else {
              fullMatch = false;
            }
          }
        });
        const parsed = [];
        wordsMatch.forEach(word => {
          if (word.match) {
            parsed.push(this.highlightMatch(word.text, word.start, word.end));
          }
          else {
            parsed.push(word.text);
          }
        });
        data.parsedLabel = parsed.join(' ');
        if (exactly) {
          const added = exactlyMatch.find(a => a.index == data.index);
          if (added == undefined) {
            exactlyMatch.push(data);
          }
        }
        else {
          if (fullMatch) {
            const added = andMatch.find(a => a.index == data.index);
            if (added == undefined) {
              andMatch.push(data);
            }
          }
          else if (!fullMatch && match) {
            const added = orMatch.find(a => a.index == data.index);
            if (added == undefined) {
              orMatch.push(data);
            }
          }
        }
      });
      this._filteredData = exactlyMatch.concat(andMatch.concat(orMatch));
      this.renderFilteredResults();
    };
    /** Renderiza los resultados en la vista en base al filtro y ordenamiento */
    this.renderFilteredResults = () => {
      if (this._htmlResults.length >= this._filteredData.length) {
        this._htmlResults.forEach((html, index) => {
          const filtered = this._filteredData[index];
          if (filtered != undefined && index <= 5) {
            html.setAttribute('label', filtered.parsedLabel);
            html.setAttribute('value', filtered.value);
          }
          else {
            html.remove();
          }
        });
      }
      else {
        this._filteredData.forEach((filtered, index) => {
          const html = this._htmlResults[index];
          if (html == undefined && index <= 5) {
            const nodeResult = document.createElement('ibk-search-result');
            nodeResult.setAttribute('label', filtered.parsedLabel);
            nodeResult.setAttribute('value', filtered.value);
            const resultsContainer = this.host.querySelector('.ibk-searchbar__results');
            resultsContainer.appendChild(nodeResult);
          }
          else if (html != undefined) {
            html.setAttribute('label', filtered.parsedLabel);
            html.setAttribute('value', filtered.value);
          }
        });
      }
    };
    /** Resalta la coincidencia de la búsqueda y el resultado */
    this.highlightMatch = (label, startMatch, endMatch) => {
      const isFormated = label.search('ibk-search-result__match');
      if (isFormated < 0) {
        let formated = label.split('');
        formated.splice(startMatch, 0, '<strong class="ibk-search-result__match">');
        formated.splice(endMatch + 1, 0, '</strong>');
        return formated.join('');
      }
      else {
        return label;
      }
    };
    this.clear = () => {
      this.value = '';
      const html = this.host.querySelectorAll('ibk-search-result');
      Array.from(html, (html) => html.remove());
      this.empty = false;
    };
  }
  componentDidLoad() {
    this._benefitModule = this.benefit != undefined && this._benefitModule == undefined ? 1 : this._benefitModule;
  }
  componentWillLoad() {
    this.bodyClick();
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-searchbar', [
      `icon-${this.iconPosition}`,
      { focus: this._focus },
      { disabled: this.disabled },
      { open: this._open },
      { boxed: this.boxed }
    ]);
  }
  onSearchbarFocusIn() {
    this._focus = true;
    this.benefit && (this._open = true);
  }
  onSearchbarFocusOut() {
    this._focus = false;
  }
  bodyClick() {
    document.body.addEventListener('click', e => {
      const t = e.target;
      const benefitContainer = t.closest('.ibk-searchbar__benefit');
      const inputContainer = t.closest('.ibk-searchbar__input');
      if (benefitContainer == null && inputContainer == null) {
        this._focus = false;
        this._open = false;
      }
      else {
        this.host.querySelector('.ibk-searchbar__value').focus();
      }
    });
  }
  onNavigate(e) {
    if (this.value.length >= 3 && this._focus) {
      this.navigate(e.keyCode);
    }
  }
  setBenefitModule(e) {
    const t = e.target;
    if (!t.matches('ibk-search-result')) {
      this._benefitModule = parseInt(t.getAttribute('data-code'));
      const primary = t.querySelector('.ibk-button--primary');
      if (primary == null && this.value.length >= 3 && this._benefitModule != 5) {
        this._htmlResults.forEach((html) => html.remove());
        this._resultData = [];
        this._filteredData = [];
        this.host.setAttribute('loading', '');
        this.onsearch.emit({ value: this.value.slice(0, 3), benefitModule: this._benefitModule });
        this.createObjectFromResult();
      }
      allSiblings(t).forEach((sib) => sib.setAttribute('appearance', 'secondary'));
      t.setAttribute('appearance', 'primary');
      this.onbenefitclick.emit(this._benefitModule);
      if (this._benefitModule == 5) {
        setTimeout(() => {
          this.host.querySelector('.ibk-searchbar__value').blur();
          this._focus = false;
          this._open = false;
          this.clear();
        }, 100);
      }
    }
  }
  render() {
    return (h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && h("span", { class: "ibk-searchbar__label" }, this.label), this.subtitle && h("span", { class: "ibk-searchbar__subtitle" }, this.subtitle), h("label", { class: "ibk-searchbar__input" }, this.iconPosition == 'left' && h("i", { class: "ibk-searchbar__icon-search icon-m-search" }), h("input", { class: "ibk-searchbar__value", type: "text", onInput: this.search, placeholder: this.placeholder, value: this.value }), this.value.length >= 1 && h("i", { class: "ibk-searchbar__icon-clear icon-m-status-error", onClick: this.clear }), this.iconPosition == 'right' && h("i", { class: "ibk-searchbar__icon-search icon-m-search" })), h("div", { class: "ibk-searchbar__results" }, this.benefit &&
      h("div", { class: "ibk-searchbar__benefit" }, h("p", { class: "ibk-searchbar__benefit-label" }, "Buscar en"), h("div", { class: "ibk-searchbar__benefit-links" }, h("ibk-button", { "data-code": "1", appearance: "primary", text: "Productos" }), h("ibk-button", { "data-code": "2", appearance: "secondary", text: "Vales y giftcards" }), h("ibk-button", { "data-code": "4", appearance: "secondary", text: "Canje en tiendas" }), h("ibk-button", { "data-code": "5", appearance: "secondary", text: "Viajes", icon: "icon-xs-arrow-right-2" }))), this.loading &&
      h("div", { class: "ibk-searchbar__loading" }, h("span", { class: "ibk-searchbar__loading-icon" }), h("span", { class: "ibk-searchbar__loading-text" }, "Buscando")), this.empty && !this.loading &&
      h("div", { class: "ibk-searchbar__empty" }, h("p", { class: "ibk-searchbar__empty-message" }, "No se encontraron resultados"), this.shopstarRedirect &&
        h("div", { class: "ibk-searchbar__shopstar" }, h("p", { class: "ibk-searchbar__shopstar-text" }, "Visita ", h("img", { class: "ibk-searchbar__shopstar-img", src: getAssetPath('../assets/images/logo-shopstar.png'), alt: "Shopstar" }), " para continuar con tu b\u00FAsqueda y canjear tus Millas por productos."), h("ibk-button", { class: "ibk-searchbar__shopstar-btn", text: "Ir ahora", href: "https://shopstar.pe/", appearance: "secondary", "href-target": "_blank" }))), h("slot", null))));
  }
  get host() { return this; }
  static get style() { return searchbarCss; }
};

const tableCss = ".ibk-table{width:100%;box-sizing:border-box;color:var(--grayText);font-family:var(--fontMontserrat);font-size:14px;text-align:left}.ibk-table *{box-sizing:border-box}.ibk-table__body{width:100%;border-radius:4px;overflow:auto;box-shadow:0 2px 4px 0 var(--gray4)}.ibk-table__body::-webkit-scrollbar{height:4px;width:4px;background-color:var(--gray5)}.ibk-table__body::-webkit-scrollbar-thumb{background-color:var(--gray3);border-radius:2px}.ibk-table__container{border-collapse:collapse;width:100%}.ibk-table__row:not(:last-child){border-bottom:1px solid var(--gray4)}.ibk-table__row--heading{font-family:var(--fontGeometria);background-color:#f7f9f8}.ibk-table__cell{padding:15px 10px}.ibk-table__cell:first-child{padding-left:40px}.ibk-table--enumerate .ibk-table__cell:first-child{text-align:center;width:100px;font-size:12px;color:var(--gray2);font-weight:500}.ibk-table__cell:last-child{padding-right:40px}.ibk-table--selectable .ibk-table__row:not(.ibk-table__row--heading){cursor:pointer;transition:var(--fast)}.ibk-table--selectable .ibk-table__row:not(.ibk-table__row--heading):hover{background-color:var(--gray5)}.ibk-table--selectable.ibk-table--enumerate .ibk-table__cell:nth-child(2){width:50px;text-align:center}.ibk-table--selectable:not(.ibk-table--enumerate) .ibk-table__cell:nth-child(1){width:100px;text-align:center}.ibk-table__footer{position:relative;height:48px;margin-top:20px;display:flex;align-items:center;justify-content:center}.ibk-table__paginator{display:flex;align-items:center;position:absolute;top:0;right:0}.ibk-table__page-current{appearance:none;-webkit-appearance:none;-moz-appearance:none;border:1px solid var(--gray4);border-radius:4px;width:48px;padding:0 5px;height:48px;outline:none;text-align:center;font-family:var(--fontGeometria);font-weight:500;font-size:16px;margin-right:7px;transition:var(--fast)}.ibk-table__page-current:hover{border-color:var(--gray3)}.ibk-table__page-current:focus{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-table__page-total{user-select:none}.ibk-table__page-total strong{font-weight:600}.ibk-table__page-prev,.ibk-table__page-next{font-size:12px;width:50px;text-align:center;cursor:pointer;color:var(--primaryGreen1)}.ibk-table__page-prev:active,.ibk-table__page-next:active{transform:translateY(1px)}.ibk-table__page-prev--disabled,.ibk-table__page-next--disabled{pointer-events:none;color:var(--gray3)}.ibk-table__rows-selector{position:absolute;top:0;left:0}.ibk-table__rows-dropdown{display:inline-block;width:80px;margin-right:7px}.ibk-table__rows-dropdown .ibk-dropdown__error-message{display:none}.ibk-table__cell-actions{min-width:130px;max-width:130px;width:130px}.ibk-table__action{color:var(--primaryGreen1);font-size:16px;display:inline-block;vertical-align:middle}.ibk-table__action:active{transform:translateY(1px)}.ibk-table__action:not(:last-child){margin-right:10px}";

const IbkTable = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onselect = createEvent(this, "onselect", 7);
    this.ondetail = createEvent(this, "ondetail", 7);
    this.onedit = createEvent(this, "onedit", 7);
    this.ondelete = createEvent(this, "ondelete", 7);
    /** Se eliminará el estilo por defecto de la primera fila */
    this.notHeading = false;
    /** Agregará una columna al inicio con un botón para selección  */
    this.selectable = false;
    /** Define si se mostrará una numeración por cada fila */
    this.enumerate = false;
    /** Define cuantas filas se mostrarán por página */
    this.rowsPerPage = 5;
    /** Define la página actual del paginador */
    this.currentPage = 1;
    /** Define si se mostrará un resumen de filas en la parte inferior */
    this.showInfo = false;
    /** Define si se mostrará el selector de filas */
    this.rowsSelector = false;
    /** Define los rangos que se podrán seleccionar en el selector de filas
     * Se ingresará como valor números separados por comas
     * Si se desea que el la última opción sea mostrar todas las filas se colocará "all", por ejm: "5,10,all"
     */
    this.rowsToShow = "5,10,15,20,all";
    /** Especifica si la columna a ordenar tiene un tipo de dato concreto
     * Los valores pueden ser 'text', 'date' o 'number'
     * Por defecto se ordenará con el tipo texto
     * Si el tipo es date, la fecha deberá estar en formato dd/mm/yyyy
     */
    this.sortDataType = 'text';
    /** Almacena los índices seleccionados de la tabla */
    this._tempIndexes = new Array();
    /** Almacenará toda la información de la tabla */
    this._tableInfo = new Array();
    /** Almacenará la información a mostrar en la tabla (página actual) */
    this._currentTableInfo = new Array();
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-table', [
        { selectable: this.selectable },
        { enumerate: this.enumerate }
      ]);
    };
    /** A partir de la tabla creada por el usuario, se creará un objeto con la información de la tabla */
    this.createObjectFromHtml = () => {
      const table = this.host.querySelector('table');
      const rows = table.querySelectorAll('tr');
      rows.forEach((row, index) => {
        const rowInfo = {};
        const cells = row.querySelectorAll('th, td');
        if (this.columnOfId) {
          rowInfo.id = (!this.notHeading && index > 0 || this.notHeading) ? cells[this.columnOfId - 1].innerHTML : 0;
        }
        else {
          rowInfo.id = !this.notHeading ? index : (index + 1);
        }
        rowInfo.cells = [];
        if (this.enumerate) {
          if (!this.notHeading) {
            rowInfo.cells.push(index > 0 ? index.toString() : '');
          }
          else {
            rowInfo.cells.push((index + 1).toString());
          }
        }
        if (this.selectable) {
          const checkboxNode = document.createElement('ibk-checkbox');
          checkboxNode.setAttribute('value', rowInfo.id);
          checkboxNode.setAttribute('icon-only', '');
          checkboxNode.classList.add('ibk-table__selector');
          rowInfo.cells.push(checkboxNode.outerHTML);
        }
        cells.forEach((cell) => {
          rowInfo.cells.push(cell.innerHTML.trim());
        });
        if (this.actions) {
          if (!this.notHeading && index == 0) {
            rowInfo.cells.push('<th class="ibk-table__cell">Acciones</th>');
          }
          if (!this.notHeading && index > 0 || this.notHeading) {
            rowInfo.cells.push(this.addActions(rowInfo.id));
          }
        }
        this._tableInfo.push(rowInfo);
      });
      this.sortData();
    };
    this.drawTable = () => {
      const table = this.host.querySelector('table');
      table.innerHTML = '';
      table.classList.add('ibk-table__container');
      if (this.paginator) {
        const start = !this.notHeading ? (this.currentPage * this.rowsPerPage) - this.rowsPerPage + 1 : (this.currentPage * this.rowsPerPage) - this.rowsPerPage;
        const end = !this.notHeading ? (this.currentPage * this.rowsPerPage) + 1 : (this.currentPage * this.rowsPerPage);
        this._currentTableInfo = this._tableInfo.slice(start, end);
        !this.notHeading && this._currentTableInfo.unshift(this._tableInfo[0]);
      }
      else {
        this._currentTableInfo = this._tableInfo;
      }
      this._currentTableInfo.forEach((rows, index) => {
        const rowNode = document.createElement('tr');
        rowNode.classList.add('ibk-table__row');
        !this.notHeading && index == 0 && rowNode.classList.add('ibk-table__row--heading');
        rows.cells.forEach((cell, i) => {
          const cellNode = document.createElement((!this.notHeading && index == 0) ? 'th' : 'td');
          cellNode.innerHTML = cell;
          cellNode.classList.add('ibk-table__cell');
          if (!this.notHeading && i == rows.cells.length - 1) {
            cellNode.classList.add('ibk-table__cell-actions');
          }
          rowNode.appendChild(cellNode);
        });
        table.appendChild(rowNode);
      });
      this.selectRow();
      this.emitAction();
    };
    /** Función que se ejecuta al seleccionar alguna fila de la tabla */
    this.selectRow = () => {
      const checkboxes = this.host.querySelectorAll('ibk-checkbox');
      checkboxes.forEach((check) => {
        check.addEventListener('onchecked', (e) => {
          if (!this.notHeading && e.detail.value == '0') {
            this._tempIndexes = new Array();
            const rows = this.host.querySelectorAll('.ibk-table__row');
            rows.forEach((row, index) => {
              if (e.detail.checked) {
                if (index != 0) {
                  const id = row.querySelector('.ibk-table__selector').getAttribute('value');
                  this._tempIndexes.push(id);
                  row.querySelector('.ibk-table__selector').setAttribute('checked', '');
                }
              }
              else {
                row.querySelector('.ibk-table__selector').removeAttribute('checked');
              }
            });
          }
          else if ((e.detail.value == '0' && this.notHeading) || e.detail.value != '0') {
            if (!this.notHeading) {
              checkboxes[0].removeAttribute('checked');
            }
            if (e.detail.checked) {
              this._tempIndexes.push(e.detail.value);
            }
            else {
              const idx = this._tempIndexes.indexOf(e.detail.value);
              this._tempIndexes.splice(idx, 1);
            }
          }
          this.onselect.emit(this._tempIndexes);
        });
      });
    };
    /** Configuración del paginador */
    this.configPaginator = () => {
      if (!this._pages) {
        const bodyTable = !this.notHeading ? this._tableInfo.length - 1 : this._tableInfo.length;
        this._pages = Math.ceil(bodyTable / this.rowsPerPage);
      }
      if (this.currentPage >= this._pages) {
        this.currentPage = this._pages;
      }
      else if (this.currentPage < 1) {
        this.currentPage = 1;
      }
    };
    /** Función que maneja el avance o retroceso de las páginas */
    this.handlerPaginator = (action) => {
      if (action == 'next') {
        this.currentPage++;
      }
      else {
        this.currentPage--;
      }
      const start = !this.notHeading ? (this.currentPage * this.rowsPerPage) - this.rowsPerPage + 1 : (this.currentPage * this.rowsPerPage) - this.rowsPerPage;
      const end = !this.notHeading ? (this.currentPage * this.rowsPerPage) + 1 : (this.currentPage * this.rowsPerPage);
      this._currentTableInfo = new Array();
      this._currentTableInfo = this._tableInfo.slice(start, end);
      !this.notHeading && this._currentTableInfo.unshift(this._tableInfo[0]);
      this.drawTable();
    };
    /** Validar que se ingrese un número en el campo de texto del paginador */
    this.validateEntryPage = e => {
      if (!regexValidators.number.test(e.key) && (e.keyCode != 8 && e.keyCode != 9) && !(e.keyCode >= 37 && e.keyCode <= 40)) {
        e.preventDefault();
      }
    };
    /** Función que se ejecuta al escribir manualmente la página */
    this.editPage = e => {
      const t = e.target;
      const newPage = t.value;
      if (newPage < 1) {
        this.currentPage = 1;
      }
      else if (newPage > this._pages) {
        this.currentPage = this._pages;
      }
      else {
        this.currentPage = newPage;
      }
      const field = this.host.querySelector('.ibk-table__page-total');
      field.value = this.currentPage.toString();
      this.drawTable();
    };
    this.setRowsDropdown = () => {
      setTimeout(() => {
        const dropdown = this.host.querySelector('.ibk-table__rows-dropdown');
        this.rowsToShow.split(',').forEach((number, index) => {
          const child = document.createElement('ibk-dropdown-item');
          child.setAttribute('value', number == 'all' ? this._tableInfo.length.toString() : number);
          child.setAttribute('label', number == 'all' ? 'Todos' : number);
          index == 0 && child.setAttribute('selected', '');
          dropdown.appendChild(child);
        });
        dropdown.addEventListener('onchange', (e) => {
          this.rowsPerPage = parseInt(e.detail.value);
          const bodyTable = !this.notHeading ? this._tableInfo.length - 1 : this._tableInfo.length;
          this._pages = Math.ceil(bodyTable / this.rowsPerPage);
          this.drawTable();
        });
      }, 10);
    };
    /** Función que ordena las filas de la tabla dependiendo del dato enviado en el parámetro sort */
    this.sortData = () => {
      if (this.sort) {
        const tempTable = this._tableInfo.slice();
        const firstRow = !this.notHeading ? tempTable.shift() : null;
        const sortData = {
          id: parseInt(this.sort.split(',')[0]),
          type: this.sort.split(',')[1]
        };
        if (this.selectable && this.enumerate) {
          sortData.id++;
        }
        else if ((!this.selectable && this.enumerate) || (this.selectable && !this.enumerate)) ;
        else if (!this.selectable && !this.enumerate) {
          sortData.id--;
        }
        tempTable.sort((a, b) => {
          let compare1, compare2;
          if (this.sortDataType == 'text') {
            compare1 = a.cells[sortData.id].toLowerCase();
            compare2 = b.cells[sortData.id].toLowerCase();
          }
          else if (this.sortDataType == 'number') {
            compare1 = parseInt(a.cells[sortData.id]);
            compare2 = parseInt(b.cells[sortData.id]);
          }
          else if (this.sortDataType == 'date') {
            let dateA = a.cells[sortData.id].split('/');
            let dateB = b.cells[sortData.id].split('/');
            compare1 = new Date(dateA[2], dateA[1], dateA[0]);
            compare2 = new Date(dateB[2], dateB[1], dateB[0]);
          }
          if (sortData.type == 'asc') {
            return compare1 <= compare2 ? -1 : 1;
          }
          else {
            return compare1 > compare2 ? -1 : 1;
          }
        });
        this._tableInfo = tempTable;
        !this.notHeading && this._tableInfo.unshift(firstRow);
      }
    };
    /** Función que agrega la columna de acciones dependiendo del dato enviado en el parámetro actions */
    this.addActions = (id) => {
      if (this.actions) {
        const actions = this.actions.split(',');
        let htmlActions = '';
        actions.forEach((action) => {
          const actionNode = document.createElement('i');
          actionNode.classList.add('ibk-table__action');
          actionNode.setAttribute('data-id', id);
          actionNode.setAttribute('data-action', action);
          if (action == 'detail') {
            actionNode.classList.add('icon-m-eye-on', 'ibk-table__action--detail');
          }
          else if (action == 'edit') {
            actionNode.classList.add('icon-m-edit', 'ibk-table__action--edit');
          }
          else if (action == 'delete') {
            actionNode.classList.add('icon-m-trash', 'ibk-table__action--delete');
          }
          htmlActions += actionNode.outerHTML;
        });
        return htmlActions;
      }
    };
    this.emitAction = () => {
      const actions = this.host.querySelectorAll('.ibk-table__action');
      actions.forEach((action) => {
        action.addEventListener('click', e => {
          const t = e.target;
          const action = t.getAttribute('data-action');
          const id = t.getAttribute('data-id');
          if (action == 'detail') {
            this.ondetail.emit(id);
          }
          else if (action == 'edit') {
            this.onedit.emit(id);
          }
          else if (action == 'delete') {
            this.ondelete.emit(id);
          }
        });
      });
    };
    /** Función que filtrará la información de la tabla basado en el valor de la propiedad filteredText */
    this.setFilteredText = () => {
    };
  }
  componentWillLoad() {
    this.createObjectFromHtml();
    this.drawTable();
    this.configPaginator();
    this.setRowsDropdown();
  }
  render() {
    return (h("div", { class: this.containerClass() }, h("div", { class: "ibk-table__body" }, h("slot", null)), this.paginator &&
      h("div", { class: "ibk-table__footer" }, this.rowsSelector &&
        h("div", { class: "ibk-table__rows-selector" }, h("ibk-dropdown", { class: "ibk-table__rows-dropdown", "no-handling-error": true }), h("span", null, "\u00F3rdenes por p\u00E1gina")), this.showInfo &&
        h("div", { class: "ibk-table__showing" }, h("span", null, "Mostrando", h("strong", null, " ", (this.currentPage * this.rowsPerPage) - this.rowsPerPage + 1, " - ", (this.currentPage * this.rowsPerPage > this._tableInfo.length ? this._tableInfo.length : this.currentPage * this.rowsPerPage)), " de", h("strong", null, " ", !this.notHeading ? this._tableInfo.length - 1 : this._tableInfo.length, " "), "\u00F3rdenes")), h("div", { class: "ibk-table__paginator" }, h("i", { class: "ibk-table__page-prev icon-xs-arrow-left" + (this.currentPage == 1 ? ' ibk-table__page-prev--disabled' : ''), onClick: () => this.handlerPaginator('prev') }), h("input", { class: "ibk-table__page-current", type: "text", value: this.currentPage, onKeyDown: this.validateEntryPage, onInput: this.editPage }), h("span", { class: "ibk-table__page-total" }, "de ", h("strong", null, this._pages)), h("i", { class: "ibk-table__page-next icon-xs-arrow-right" + (this.currentPage == this._pages ? ' ibk-table__page-next--disabled' : ''), onClick: () => this.handlerPaginator('next') })))));
  }
  get host() { return this; }
  static get style() { return tableCss; }
};

const tagCss = ".ibk-tag{box-sizing:border-box;background-color:var(--primaryGreen1);display:inline-flex;align-items:center;justify-content:center;text-align:center;border-radius:30px;padding:10px 15px;border:1px solid transparent;cursor:default}.ibk-tag *{box-sizing:border-box}.ibk-tag__text{color:white;font-family:var(--fontGeometria);font-weight:500;font-size:14px}.ibk-tag__icon{color:white}.ibk-tag--icon-left .ibk-tag__icon{margin-right:7px}.ibk-tag--icon-right .ibk-tag__icon{order:2;margin-left:7px}.ibk-tag--outline{background-color:transparent;border-color:var(--primaryGreen1)}.ibk-tag--outline .ibk-tag__text,.ibk-tag--outline .ibk-tag__icon{color:var(--primaryGreen1)}";

const IbkTag = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /** Define la posición del ícono a mostrar */
    this.iconPosition = 'left';
    /** El tag solo usará el color en el borde */
    this.outline = false;
    /** Configura la clase del componente basado en estados y modificadores */
    this.containerClass = () => {
      return modifiersToClass('ibk-tag', [
        `icon-${this.iconPosition}`,
        { outline: this.outline }
      ]);
    };
  }
  render() {
    var _a, _b;
    return (h("div", { class: this.containerClass(), style: { backgroundColor: !this.outline && this.color, borderColor: this.outline && this.color, width: `${this.width}px` } }, this.icon && h("i", { class: this.icon + ' ibk-tag__icon', style: { color: (_a = this.textColor) !== null && _a !== void 0 ? _a : (this.outline && this.color) } }), h("span", { class: "ibk-tag__text", style: { color: (_b = this.textColor) !== null && _b !== void 0 ? _b : (this.outline && this.color) } }, this.text)));
  }
  static get style() { return tagCss; }
};

const textfieldCss = ".ibk-textfield{width:100%;box-sizing:border-box}.ibk-textfield *{box-sizing:border-box}.ibk-textfield__label{font-family:var(--fontGeometria);font-size:14px;padding-bottom:5px;display:block;font-weight:500;color:var(--gray1)}.ibk-textfield__subtitle{font-family:var(--fontMontserrat);color:var(--grayText);font-size:14px;font-weight:500;padding-bottom:7px;display:block}.ibk-textfield__input{display:flex;align-items:center;width:100%;border:1px solid var(--gray4);border-radius:4px;height:48px;transition:var(--fast);background-color:white}@media screen and (max-width: 360px){.ibk-textfield__input{height:44px}}.ibk-textfield__input:hover{border-color:var(--gray3)}.ibk-textfield__value{width:100%;appearance:none;-webkit-appearance:none;-moz-appearance:none;border:none;outline:none;display:block;height:100%;padding:0 15px;font-family:var(--fontGeometria);font-size:16px;font-weight:500;color:var(--grayText);background-color:transparent}.ibk-textfield__value::placeholder{color:var(--gray2);font-weight:400}.ibk-textfield__value::-ms-reveal,.ibk-textfield__value::-ms-clear{display:none}.ibk-textfield__value::-webkit-outer-spin-button,.ibk-textfield__value::-webkit-inner-spin-button{-webkit-appearance:none;margin:0}.ibk-textfield--focus .ibk-textfield__input{border-color:var(--primaryGreen1);box-shadow:inset 0 0 0 0.5px var(--primaryGreen1)}.ibk-textfield__trailing-icon{padding-right:15px;color:var(--primaryGreen1);cursor:text}.ibk-textfield__leading-icon{padding-left:15px;color:var(--primaryGreen1);cursor:text}.ibk-textfield--erasable .ibk-textfield__trailing-icon{color:var(--gray1)}.ibk-textfield--password .ibk-textfield__trailing-icon,.ibk-textfield--erasable .ibk-textfield__trailing-icon{cursor:pointer}.ibk-textfield--password .ibk-textfield__trailing-icon:active,.ibk-textfield--erasable .ibk-textfield__trailing-icon:active{transform:translateY(1px)}.ibk-textfield--error .ibk-textfield__input{border-color:var(--extendedWatermelon1)}.ibk-textfield--error.ibk-textfield--focus .ibk-textfield__input{box-shadow:inset 0 0 0 0.5px var(--extendedWatermelon1)}.ibk-textfield--error .ibk-textfield__trailing-icon,.ibk-textfield--error .ibk-textfield__leading-icon{color:var(--extendedWatermelon1)}.ibk-textfield__error-message{font-family:var(--fontMontserrat);font-size:12px;color:var(--extendedWatermelon1);font-weight:500;margin-top:7px;display:block;min-height:15px}.ibk-textfield--disabled{cursor:default;pointer-events:none}.ibk-textfield--disabled .ibk-textfield__input{background-color:var(--gray5)}";

const IbkTextfield = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.onchange = createEvent(this, "onchange", 7);
    this.onfocus = createEvent(this, "onfocus", 7);
    /** Tipo de contenido que se ingresará en el campo de texto */
    this.type = 'text';
    /** Cuando se encuentra dentro de un "ibk-form" al hacer submit si el campo de texto se encuentra vacío, mostrará un mensaje de error */
    this.required = false;
    /** Personaliza el mensaje de campo requerido */
    this.requiredMessage = 'Este campo es requerido';
    /** Se mostrará un mensaje de error */
    this.error = false;
    /** Personaliza el mensaje de error */
    this.errorMessage = 'Por favor, ingrese este campo correctamente';
    /** Contenido del campo de texto */
    this.value = '';
    /** Define si el textfield no contará con manejo de errores. Se omitirá el espacio generado para el mensaje de error */
    this.noHandlingError = false;
    /** Muestra un icono a la izquierda con una X que sirve para borrar el contenido del campo de texto */
    this._erasable = false;
    /** Estado activo o inactivo del campo de texto */
    this._focus = false;
    /** Estado que determina si la contraseña está visible o no */
    this._showingPwd = false;
    /** Configura el tipo de campo de texto en base a la configuración del componente */
    this.setInputType = () => {
      let type = '';
      if (this.type == 'password' && !this._showingPwd) {
        type = 'password';
      }
      else if (this.type == 'date') {
        type = this.type;
      }
      else {
        type = 'text';
      }
      return type;
    };
    /** Define el máximo de caracteres en base a la configuración del componente */
    this.setMaxLength = () => {
      let length = 0;
      if (this.type == 'expiration') {
        length = 5;
      }
      else if (this.type == 'cvv') {
        length = 4;
      }
      else if (this.type == 'dni') {
        length = 8;
      }
      else if (this.type == 'document') {
        length = 16;
      }
      else if (this.type == 'phone') {
        length = 9;
      }
      return length;
    };
    /** Configura el icono del lado izquierdo en base a la configuración del componente */
    this.setTrailingIcon = () => {
      let icon = '';
      if (this.type == 'password') {
        icon = this._showingPwd ? 'icon-m-eye-off' : 'icon-m-eye-on';
      }
      else if (this._erasable) {
        icon = 'icon-m-status-error';
      }
      else if (this.trailingIcon) {
        icon = this.trailingIcon;
      }
      return icon;
    };
    /** Determina la función a realizar en base al icono actual */
    this.trailingIconFunction = () => {
      if (this.type == 'password') {
        this._showingPwd = !this._showingPwd;
      }
      else if (this._erasable) {
        const input = this.host.querySelector('.ibk-textfield__value');
        input.value = '';
        this._erasable = false;
      }
    };
    /** Determina el mensaje de error a mostrar en base a la configuración del componente */
    this.setErrorMessage = () => {
      let msg = '';
      if (this.required && this.error && this.value.length == 0) {
        msg = this.requiredMessage;
      }
      else if (this.error) {
        msg = this.errorMessage;
      }
      return msg;
    };
    /** Escucha y emite el evento editing cuando cambia el contenido */
    this.onInputChange = (e) => {
      const t = e.target;
      this.value = t.value;
      if (this.value != '') {
        this.host.removeAttribute('error');
        this._erasable = true;
      }
      else {
        this._erasable = false;
      }
      if (this.type == 'expiration' && t.value.length == 2 && this._keyCode != 8) {
        this.value += '/';
      }
      if (this._grouper != null) {
        this._grouper.removeAttribute('error');
      }
      this.onchange.emit(t.value);
    };
  }
  componentWillLoad() {
    this._grouper = this.host.closest('ibk-form-group');
  }
  onInputFocusIn() {
    this._focus = true;
    this.onfocus.emit('in');
  }
  onInputFocusOut() {
    this._focus = false;
    this.onfocus.emit('out');
    /** Validación para fecha de expiración */
    if (this.type == 'expiration' && this.value.length == 5) {
      const exp = this.value.split('/');
      const currentYear = new Date().getFullYear().toString();
      const formatYear = currentYear.slice(2);
      if (parseInt(exp[0]) > 12 || parseInt(exp[1]) < parseInt(formatYear)) {
        this.host.setAttribute('error', '');
      }
    }
  }
  /** Configura la clase del componente basado en estados y modificadores */
  containerClass() {
    return modifiersToClass('ibk-textfield', [
      this.type,
      { focus: this._focus },
      { erasable: this._erasable },
      { error: this.error },
      { disabled: this.disabled }
    ]);
  }
  onKeyDown(e) {
    this._keyCode = e.keyCode;
    if (['expiration', 'cvv', 'dni'].includes(this.type) && !regexValidators.number.test(e.key) && (this._keyCode != 8 && this._keyCode != 9)) {
      e.preventDefault();
    }
    else if (this.type == 'number' && !regexValidators.numberFormat.test(e.key) && (this._keyCode != 8 && this._keyCode != 9)) {
      e.preventDefault();
    }
  }
  render() {
    var _a;
    return (h("div", { class: this.containerClass(), style: { width: this.width + 'px' } }, this.label && h("span", { class: "ibk-textfield__label" }, this.label), this.subtitle && h("span", { class: "ibk-textfield__subtitle" }, this.subtitle), h("label", { class: "ibk-textfield__input" }, this.leadingIcon && h("i", { class: 'ibk-textfield__leading-icon ' + this.leadingIcon }), h("input", { class: "ibk-textfield__value", type: this.setInputType(), placeholder: this.placeholder, maxLength: (_a = this.maxLength) !== null && _a !== void 0 ? _a : (this.setMaxLength() > 0 ? this.setMaxLength() : null), value: this.value, onInput: this.onInputChange }), this.setTrailingIcon() != '' && h("i", { class: 'ibk-textfield__trailing-icon ' + this.setTrailingIcon(), onClick: this.trailingIconFunction })), !this.noHandlingError && h("span", { class: "ibk-textfield__error-message" }, this.setErrorMessage())));
  }
  get host() { return this; }
  static get style() { return textfieldCss; }
};

const tooltipCss = "";

const IbkTooltip = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
  }
  render() {
    return (h("div", { class: "ibk-tooltip" }, "Tooltip"));
  }
  static get style() { return tooltipCss; }
};

const IbkBadge$1 = /*@__PURE__*/proxyCustomElement(IbkBadge, [0,"ibk-badge",{"type":[1],"text":[1],"position":[1]}]);
const IbkBreadcrumb$1 = /*@__PURE__*/proxyCustomElement(IbkBreadcrumb, [4,"ibk-breadcrumb",{"separators":[4],"negative":[4]}]);
const IbkBreadcrumbItem$1 = /*@__PURE__*/proxyCustomElement(IbkBreadcrumbItem, [0,"ibk-breadcrumb-item",{"current":[4],"href":[1],"text":[1],"negative":[4]}]);
const IbkButton$1 = /*@__PURE__*/proxyCustomElement(IbkButton, [0,"ibk-button",{"appearance":[1],"color":[1],"text":[1],"size":[1],"type":[1],"negative":[4],"loading":[4],"icon":[1],"iconPosition":[1,"icon-position"],"full":[4],"center":[4],"disable":[4],"href":[1],"hrefTarget":[1,"href-target"]}]);
const IbkButtonInline$1 = /*@__PURE__*/proxyCustomElement(IbkButtonInline, [0,"ibk-button-inline",{"text":[1],"icon":[1],"iconPosition":[1,"icon-position"],"disable":[4],"href":[1],"hrefTarget":[1,"href-target"]}]);
const IbkCalendar$1 = /*@__PURE__*/proxyCustomElement(IbkCalendar, [0,"ibk-calendar",{"label":[1],"subtitle":[1],"placeholder":[1],"months":[2],"showMonth":[1,"show-month"],"openTo":[1,"open-to"],"initialDate":[1,"initial-date"],"endDate":[1,"end-date"],"selectedDate":[1,"selected-date"],"selectedDates":[1,"selected-dates"],"multiselect":[4],"full":[4],"rangeSelector":[1,"range-selector"],"error":[4],"required":[4],"requiredMessage":[1,"required-message"],"noHandlingError":[4,"no-handling-error"],"_showingDates":[32],"_datesPosition":[32],"_currentDate":[32],"_otherDate":[32],"_tempOverRange":[32]}]);
const IbkCheckbox$1 = /*@__PURE__*/proxyCustomElement(IbkCheckbox, [0,"ibk-checkbox",{"value":[8],"label":[1],"checked":[4],"disabled":[4],"error":[4],"required":[4],"requiredMessage":[1,"required-message"],"full":[4],"iconPosition":[1,"icon-position"],"outline":[4],"_grouped":[32],"_focus":[32]},[[0,"change","changeCheckbox"],[0,"keydown","onPressEnter"],[0,"focusin","onRadioFocusIn"],[0,"focusout","onRadioFocusOut"]]]);
const IbkCheckboxGroup$1 = /*@__PURE__*/proxyCustomElement(IbkCheckboxGroup, [4,"ibk-checkbox-group",{"subtitle":[1],"inline":[4],"error":[4],"required":[4],"requiredMessage":[1,"required-message"]}]);
const IbkDrawer$1 = /*@__PURE__*/proxyCustomElement(IbkDrawer, [4,"ibk-drawer",{"position":[1],"backgroundColor":[1,"background-color"],"show":[4],"container":[1]}]);
const IbkDropdown$1 = /*@__PURE__*/proxyCustomElement(IbkDropdown, [4,"ibk-dropdown",{"label":[1],"subtitle":[1],"placeholder":[1],"error":[4],"required":[4],"requiredMessage":[1,"required-message"],"searcher":[4],"searcherPlaceholder":[1,"searcher-placeholder"],"disabled":[4],"triggerIcon":[1,"trigger-icon"],"triggerIconColor":[1,"trigger-icon-color"],"triggerText":[1,"trigger-text"],"triggerTextColor":[1,"trigger-text-color"],"keepMarked":[4,"keep-marked"],"width":[2],"noHandlingError":[4,"no-handling-error"],"_open":[32],"_selectedItem":[32],"_cleared":[32],"_mobileDevice":[32],"_grouper":[32]},[[0,"keydown","optionsNavigate"]]]);
const IbkDropdownItem$1 = /*@__PURE__*/proxyCustomElement(IbkDropdownItem, [0,"ibk-dropdown-item",{"value":[8],"label":[1],"disabled":[4],"color":[1],"selected":[4],"preselected":[4],"cardType":[1,"card-type"],"hide":[4]},[[1,"mouseover","setPreselected"],[1,"mouseleave","deletePreselected"]]]);
const IbkForm$1 = /*@__PURE__*/proxyCustomElement(IbkForm, [36,"ibk-form"]);
const IbkFormGroup$1 = /*@__PURE__*/proxyCustomElement(IbkFormGroup, [4,"ibk-form-group",{"label":[1],"subtitle":[1],"joined":[4],"fieldsWidth":[1,"fields-width"],"error":[4],"required":[4],"requiredMessage":[1,"required-message"],"_firstFocus":[32]}]);
const IbkModal$1 = /*@__PURE__*/proxyCustomElement(IbkModal, [4,"ibk-modal",{"background":[1],"heading":[1],"subtitle":[1],"fixed":[4]}]);
const IbkNotification$1 = /*@__PURE__*/proxyCustomElement(IbkNotification, [0,"ibk-notification",{"type":[1],"container":[1],"width":[8],"message":[1],"show":[4],"timeout":[2],"fixed":[4]}]);
const IbkNumberPicker$1 = /*@__PURE__*/proxyCustomElement(IbkNumberPicker, [0,"ibk-number-picker",{"size":[1],"max":[2],"min":[2],"current":[2],"editable":[4]}]);
const IbkRadio$1 = /*@__PURE__*/proxyCustomElement(IbkRadio, [0,"ibk-radio",{"value":[8],"label":[1],"selected":[4],"disabled":[4],"error":[4],"required":[4],"requiredMessage":[1,"required-message"],"iconPosition":[1,"icon-position"],"outline":[4],"full":[4],"_grouped":[32],"_focus":[32]},[[0,"change","changeRadio"],[0,"focusin","onRadioFocusIn"],[0,"focusout","onRadioFocusOut"]]]);
const IbkRadioGroup$1 = /*@__PURE__*/proxyCustomElement(IbkRadioGroup, [4,"ibk-radio-group",{"subtitle":[1],"inline":[4],"error":[4],"required":[4],"requiredMessage":[1,"required-message"]}]);
const IbkSearchResult$1 = /*@__PURE__*/proxyCustomElement(IbkSearchResult, [0,"ibk-search-result",{"value":[1],"label":[1],"href":[1],"hrefTarget":[1,"href-target"],"over":[4]},[[1,"mouseover","mouseOver"],[1,"mouseleave","mouseLeave"]]]);
const IbkSearchbar$1 = /*@__PURE__*/proxyCustomElement(IbkSearchbar, [4,"ibk-searchbar",{"placeholder":[1],"label":[1],"subtitle":[1],"disabled":[4],"width":[2],"value":[1],"loading":[4],"empty":[4],"iconPosition":[1,"icon-position"],"boxed":[4],"benefit":[4],"shopstarRedirect":[4,"shopstar-redirect"],"_open":[32],"_focus":[32],"_readyData":[32],"_htmlResults":[32]},[[0,"focusin","onSearchbarFocusIn"],[0,"focusout","onSearchbarFocusOut"],[0,"keydown","onNavigate"],[0,"onclick","setBenefitModule"]]]);
const IbkTable$1 = /*@__PURE__*/proxyCustomElement(IbkTable, [4,"ibk-table",{"notHeading":[4,"not-heading"],"selectable":[4],"enumerate":[4],"columnOfId":[2,"column-of-id"],"paginator":[4],"rowsPerPage":[2,"rows-per-page"],"currentPage":[2,"current-page"],"showInfo":[4,"show-info"],"rowsSelector":[4,"rows-selector"],"rowsToShow":[1,"rows-to-show"],"sort":[1],"sortDataType":[1,"sort-data-type"],"actions":[1],"filteredText":[1,"filtered-text"]}]);
const IbkTag$1 = /*@__PURE__*/proxyCustomElement(IbkTag, [0,"ibk-tag",{"text":[1],"icon":[1],"iconPosition":[1,"icon-position"],"color":[1],"textColor":[1,"text-color"],"outline":[4],"width":[2]}]);
const IbkTextfield$1 = /*@__PURE__*/proxyCustomElement(IbkTextfield, [0,"ibk-textfield",{"placeholder":[1],"label":[1],"type":[1],"trailingIcon":[1,"trailing-icon"],"leadingIcon":[1,"leading-icon"],"required":[4],"requiredMessage":[1,"required-message"],"error":[4],"errorMessage":[1,"error-message"],"value":[1],"subtitle":[1],"width":[2],"disabled":[4],"maxLength":[2,"max-length"],"noHandlingError":[4,"no-handling-error"],"_erasable":[32],"_focus":[32],"_showingPwd":[32],"_grouper":[32]},[[0,"focusin","onInputFocusIn"],[0,"focusout","onInputFocusOut"],[0,"keydown","onKeyDown"]]]);
const IbkTooltip$1 = /*@__PURE__*/proxyCustomElement(IbkTooltip, [0,"ibk-tooltip"]);
const defineCustomElements = (opts) => {
  if (typeof customElements !== 'undefined') {
    [
      IbkBadge$1,
  IbkBreadcrumb$1,
  IbkBreadcrumbItem$1,
  IbkButton$1,
  IbkButtonInline$1,
  IbkCalendar$1,
  IbkCheckbox$1,
  IbkCheckboxGroup$1,
  IbkDrawer$1,
  IbkDropdown$1,
  IbkDropdownItem$1,
  IbkForm$1,
  IbkFormGroup$1,
  IbkModal$1,
  IbkNotification$1,
  IbkNumberPicker$1,
  IbkRadio$1,
  IbkRadioGroup$1,
  IbkSearchResult$1,
  IbkSearchbar$1,
  IbkTable$1,
  IbkTag$1,
  IbkTextfield$1,
  IbkTooltip$1
    ].forEach(cmp => {
      if (!customElements.get(cmp.is)) {
        customElements.define(cmp.is, cmp, opts);
      }
    });
  }
};

export { IbkBadge$1 as IbkBadge, IbkBreadcrumb$1 as IbkBreadcrumb, IbkBreadcrumbItem$1 as IbkBreadcrumbItem, IbkButton$1 as IbkButton, IbkButtonInline$1 as IbkButtonInline, IbkCalendar$1 as IbkCalendar, IbkCheckbox$1 as IbkCheckbox, IbkCheckboxGroup$1 as IbkCheckboxGroup, IbkDrawer$1 as IbkDrawer, IbkDropdown$1 as IbkDropdown, IbkDropdownItem$1 as IbkDropdownItem, IbkForm$1 as IbkForm, IbkFormGroup$1 as IbkFormGroup, IbkModal$1 as IbkModal, IbkNotification$1 as IbkNotification, IbkNumberPicker$1 as IbkNumberPicker, IbkRadio$1 as IbkRadio, IbkRadioGroup$1 as IbkRadioGroup, IbkSearchResult$1 as IbkSearchResult, IbkSearchbar$1 as IbkSearchbar, IbkTable$1 as IbkTable, IbkTag$1 as IbkTag, IbkTextfield$1 as IbkTextfield, IbkTooltip$1 as IbkTooltip, defineCustomElements };
